# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Dict, List, Union

from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
from datadog_api_client.model_utils import (
    UnsetType,
    unset,
)
from datadog_api_client.v1.model.monitor import Monitor
from datadog_api_client.v1.model.check_can_delete_monitor_response import CheckCanDeleteMonitorResponse
from datadog_api_client.v1.model.monitor_group_search_response import MonitorGroupSearchResponse
from datadog_api_client.v1.model.monitor_search_response import MonitorSearchResponse
from datadog_api_client.v1.model.deleted_monitor import DeletedMonitor
from datadog_api_client.v1.model.monitor_update_request import MonitorUpdateRequest


class MonitorsApi:
    """
    `Monitors <https://docs.datadoghq.com/monitors>`_ allow you to watch a metric or check that you care about and
    notifies your team when a defined threshold has exceeded.

    For more information, see `Creating Monitors <https://docs.datadoghq.com/monitors/create/types/>`_.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self._check_can_delete_monitor_endpoint = _Endpoint(
            settings={
                "response_type": (CheckCanDeleteMonitorResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/monitor/can_delete",
                "operation_id": "check_can_delete_monitor",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "monitor_ids": {
                    "required": True,
                    "openapi_types": ([int],),
                    "attribute": "monitor_ids",
                    "location": "query",
                    "collection_format": "csv",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._create_monitor_endpoint = _Endpoint(
            settings={
                "response_type": (Monitor,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/monitor",
                "operation_id": "create_monitor",
                "http_method": "POST",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (Monitor,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._delete_monitor_endpoint = _Endpoint(
            settings={
                "response_type": (DeletedMonitor,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/monitor/{monitor_id}",
                "operation_id": "delete_monitor",
                "http_method": "DELETE",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "monitor_id": {
                    "required": True,
                    "openapi_types": (int,),
                    "attribute": "monitor_id",
                    "location": "path",
                },
                "force": {
                    "openapi_types": (str,),
                    "attribute": "force",
                    "location": "query",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._get_monitor_endpoint = _Endpoint(
            settings={
                "response_type": (Monitor,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/monitor/{monitor_id}",
                "operation_id": "get_monitor",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "monitor_id": {
                    "required": True,
                    "openapi_types": (int,),
                    "attribute": "monitor_id",
                    "location": "path",
                },
                "group_states": {
                    "openapi_types": (str,),
                    "attribute": "group_states",
                    "location": "query",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._list_monitors_endpoint = _Endpoint(
            settings={
                "response_type": ([Monitor],),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/monitor",
                "operation_id": "list_monitors",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "group_states": {
                    "openapi_types": (str,),
                    "attribute": "group_states",
                    "location": "query",
                },
                "name": {
                    "openapi_types": (str,),
                    "attribute": "name",
                    "location": "query",
                },
                "tags": {
                    "openapi_types": (str,),
                    "attribute": "tags",
                    "location": "query",
                },
                "monitor_tags": {
                    "openapi_types": (str,),
                    "attribute": "monitor_tags",
                    "location": "query",
                },
                "with_downtimes": {
                    "openapi_types": (bool,),
                    "attribute": "with_downtimes",
                    "location": "query",
                },
                "id_offset": {
                    "openapi_types": (int,),
                    "attribute": "id_offset",
                    "location": "query",
                },
                "page": {
                    "openapi_types": (int,),
                    "attribute": "page",
                    "location": "query",
                },
                "page_size": {
                    "validation": {
                        "inclusive_maximum": 1000,
                    },
                    "openapi_types": (int,),
                    "attribute": "page_size",
                    "location": "query",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._search_monitor_groups_endpoint = _Endpoint(
            settings={
                "response_type": (MonitorGroupSearchResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/monitor/groups/search",
                "operation_id": "search_monitor_groups",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "query": {
                    "openapi_types": (str,),
                    "attribute": "query",
                    "location": "query",
                },
                "page": {
                    "openapi_types": (int,),
                    "attribute": "page",
                    "location": "query",
                },
                "per_page": {
                    "openapi_types": (int,),
                    "attribute": "per_page",
                    "location": "query",
                },
                "sort": {
                    "openapi_types": (str,),
                    "attribute": "sort",
                    "location": "query",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._search_monitors_endpoint = _Endpoint(
            settings={
                "response_type": (MonitorSearchResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/monitor/search",
                "operation_id": "search_monitors",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "query": {
                    "openapi_types": (str,),
                    "attribute": "query",
                    "location": "query",
                },
                "page": {
                    "openapi_types": (int,),
                    "attribute": "page",
                    "location": "query",
                },
                "per_page": {
                    "openapi_types": (int,),
                    "attribute": "per_page",
                    "location": "query",
                },
                "sort": {
                    "openapi_types": (str,),
                    "attribute": "sort",
                    "location": "query",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._update_monitor_endpoint = _Endpoint(
            settings={
                "response_type": (Monitor,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/monitor/{monitor_id}",
                "operation_id": "update_monitor",
                "http_method": "PUT",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "monitor_id": {
                    "required": True,
                    "openapi_types": (int,),
                    "attribute": "monitor_id",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (MonitorUpdateRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._validate_existing_monitor_endpoint = _Endpoint(
            settings={
                "response_type": (dict,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/monitor/{monitor_id}/validate",
                "operation_id": "validate_existing_monitor",
                "http_method": "POST",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "monitor_id": {
                    "required": True,
                    "openapi_types": (int,),
                    "attribute": "monitor_id",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (Monitor,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._validate_monitor_endpoint = _Endpoint(
            settings={
                "response_type": (dict,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/monitor/validate",
                "operation_id": "validate_monitor",
                "http_method": "POST",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (Monitor,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

    def check_can_delete_monitor(
        self,
        monitor_ids: List[int],
    ) -> CheckCanDeleteMonitorResponse:
        """Check if a monitor can be deleted.

        Check if the given monitors can be deleted.

        :param monitor_ids: The IDs of the monitor to check.
        :type monitor_ids: [int]
        :rtype: CheckCanDeleteMonitorResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["monitor_ids"] = monitor_ids

        return self._check_can_delete_monitor_endpoint.call_with_http_info(**kwargs)

    def create_monitor(
        self,
        body: Monitor,
    ) -> Monitor:
        """Create a monitor.

        Create a monitor using the specified options.

        **Monitor Types**

        The type of monitor chosen from:

        * anomaly: ``query alert``
        * APM: ``query alert`` or ``trace-analytics alert``
        * composite: ``composite``
        * custom: ``service check``
        * event: ``event alert``
        * forecast: ``query alert``
        * host: ``service check``
        * integration: ``query alert`` or ``service check``
        * live process: ``process alert``
        * logs: ``log alert``
        * metric: ``query alert``
        * network: ``service check``
        * outlier: ``query alert``
        * process: ``service check``
        * rum: ``rum alert``
        * SLO: ``slo alert``
        * watchdog: ``event alert``
        * event-v2: ``event-v2 alert``
        * audit: ``audit alert``
        * error-tracking: ``error-tracking alert``

        **Note** : Synthetic monitors are created through the Synthetics API. See the [Synthetics API] (https://docs.datadoghq.com/api/latest/synthetics/) documentation for more information.

        **Query Types**

        **Metric Alert Query**

        Example: ``time_aggr(time_window):space_aggr:metric{tags} [by {key}] operator #``

        * ``time_aggr`` : avg, sum, max, min, change, or pct_change
        * ``time_window`` : ``last_#m`` (with ``#`` between 1 and 10080 depending on the monitor type) or ``last_#h`` (with ``#`` between 1 and 168 depending on the monitor type) or ``last_1d`` , or ``last_1w``
        * ``space_aggr`` : avg, sum, min, or max
        * ``tags`` : one or more tags (comma-separated), or *
        * `key`: a 'key' in key:value tag syntax; defines a separate alert for each tag in the group (multi-alert)
        * ``operator`` : <, <=, >, >=, ==, or !=
        * ``#`` : an integer or decimal number used to set the threshold

        If you are using the ``_change_`` or ``_pct_change_`` time aggregator, instead use ``change_aggr(time_aggr(time_window),
        timeshift):space_aggr:metric{tags} [by {key}] operator #`` with:

        * ``change_aggr`` change, pct_change
        * ``time_aggr`` avg, sum, max, min `Learn more <https://docs.datadoghq.com/monitors/create/types/#define-the-conditions>`_
        * ``time_window`` last_#m (between 1 and 2880 depending on the monitor type), last_#h (between 1 and 48 depending on the monitor type), or last_#d (1 or 2)
        * ``timeshift`` #m_ago (5, 10, 15, or 30), #h_ago (1, 2, or 4), or 1d_ago

        Use this to create an outlier monitor using the following query:
        ``avg(last_30m):outliers(avg:system.cpu.user{role:es-events-data} by {host}, 'dbscan', 7) > 0``

        **Service Check Query**

        Example: ``"check".over(tags).last(count).by(group).count_by_status()``

        * ``check`` name of the check, for example ``datadog.agent.up``
        * ``tags`` one or more quoted tags (comma-separated), or "*". for example: ``.over("env:prod", "role:db")`` ; ``over`` cannot be blank.
        * ``count`` must be at greater than or equal to your max threshold (defined in the ``options`` ). It is limited to 100.
          For example, if you've specified to notify on 1 critical, 3 ok, and 2 warn statuses, ``count`` should be at least 3.
        * ``group`` must be specified for check monitors. Per-check grouping is already explicitly known for some service checks.
          For example, Postgres integration monitors are tagged by ``db`` , ``host`` , and ``port`` , and Network monitors by ``host`` , ``instance`` , and ``url``. See `Service Checks <https://docs.datadoghq.com/api/latest/service-checks/>`_ documentation for more information.

        **Event Alert Query**

        Example: ``events('sources:nagios status:error,warning priority:normal tags: "string query"').rollup("count").last("1h")"``

        * ``event`` , the event query string:
        * ``string_query`` free text query to match against event title and text.
        * ``sources`` event sources (comma-separated).
        * ``status`` event statuses (comma-separated). Valid options: error, warn, and info.
        * ``priority`` event priorities (comma-separated). Valid options: low, normal, all.
        * ``host`` event reporting host (comma-separated).
        * ``tags`` event tags (comma-separated).
        * ``excluded_tags`` excluded event tags (comma-separated).
        * ``rollup`` the stats roll-up method. ``count`` is the only supported method now.
        * ``last`` the timeframe to roll up the counts. Examples: 45m, 4h. Supported timeframes: m, h and d. This value should not exceed 48 hours.

        **NOTE** The Event Alert Query is being deprecated and replaced by the Event V2 Alert Query. For more information, see the `Event Migration guide <https://docs.datadoghq.com/events/guides/migrating_to_new_events_features/>`_.

        **Event V2 Alert Query**

        Example: ``events(query).rollup(rollup_method[, measure]).last(time_window) operator #``

        * ``query`` The search query - following the `Log search syntax <https://docs.datadoghq.com/logs/search_syntax/>`_.
        * ``rollup_method`` The stats roll-up method - supports ``count`` , ``avg`` and ``cardinality``.
        * ``measure`` For ``avg`` and cardinality ``rollup_method`` - specify the measure or the facet name you want to use.
        * ``time_window`` #m (between 1 and 2880), #h (between 1 and 48).
        * ``operator`` ``<`` , ``<=`` , ``>`` , ``>=`` , ``==`` , or ``!=``.
        * ``#`` an integer or decimal number used to set the threshold.

        **Process Alert Query**

        Example: ``processes(search).over(tags).rollup('count').last(timeframe) operator #``

        * ``search`` free text search string for querying processes.
          Matching processes match results on the `Live Processes <https://docs.datadoghq.com/infrastructure/process/?tab=linuxwindows>`_ page.
        * ``tags`` one or more tags (comma-separated)
        * ``timeframe`` the timeframe to roll up the counts. Examples: 10m, 4h. Supported timeframes: s, m, h and d
        * ``operator`` <, <=, >, >=, ==, or !=
        * ``#`` an integer or decimal number used to set the threshold

        **Logs Alert Query**

        Example: ``logs(query).index(index_name).rollup(rollup_method[, measure]).last(time_window) operator #``

        * ``query`` The search query - following the `Log search syntax <https://docs.datadoghq.com/logs/search_syntax/>`_.
        * ``index_name`` For multi-index organizations, the log index in which the request is performed.
        * ``rollup_method`` The stats roll-up method - supports ``count`` , ``avg`` and ``cardinality``.
        * ``measure`` For ``avg`` and cardinality ``rollup_method`` - specify the measure or the facet name you want to use.
        * ``time_window`` #m (between 1 and 2880), #h (between 1 and 48).
        * ``operator`` ``<`` , ``<=`` , ``>`` , ``>=`` , ``==`` , or ``!=``.
        * ``#`` an integer or decimal number used to set the threshold.

        **Composite Query**

        Example: ``12345 && 67890`` , where ``12345`` and ``67890`` are the IDs of non-composite monitors

        * ``name`` [ *required* , *default* = **dynamic, based on query** ]: The name of the alert.
        * ``message`` [ *required* , *default* = **dynamic, based on query** ]: A message to include with notifications for this monitor.
          Email notifications can be sent to specific users by using the same '@username' notation as events.
        * ``tags`` [ *optional* , *default* = **empty list** ]: A list of tags to associate with your monitor.
          When getting all monitor details via the API, use the ``monitor_tags`` argument to filter results by these tags.
          It is only available via the API and isn't visible or editable in the Datadog UI.

        **SLO Alert Query**

        Example: ``error_budget("slo_id").over("time_window") operator #``

        * ``slo_id`` : The alphanumeric SLO ID of the SLO you are configuring the alert for.
        * `time_window`: The time window of the SLO target you wish to alert on. Valid options: ``7d`` , ``30d`` , ``90d``.
        * ``operator`` : ``>=`` or ``>``

        **Audit Alert Query**

        Example: ``audits(query).rollup(rollup_method[, measure]).last(time_window) operator #``

        * ``query`` The search query - following the `Log search syntax <https://docs.datadoghq.com/logs/search_syntax/>`_.
        * ``rollup_method`` The stats roll-up method - supports ``count`` , ``avg`` and ``cardinality``.
        * ``measure`` For ``avg`` and cardinality ``rollup_method`` - specify the measure or the facet name you want to use.
        * ``time_window`` #m (between 1 and 2880), #h (between 1 and 48).
        * ``operator`` ``<`` , ``<=`` , ``>`` , ``>=`` , ``==`` , or ``!=``.
        * ``#`` an integer or decimal number used to set the threshold.

        **NOTE** Only available on US1-FED and in closed beta on US1, EU, US3, and US5.

        **CI Pipelines Alert Query**

        Example: ``ci-pipelines(query).rollup(rollup_method[, measure]).last(time_window) operator #``

        * ``query`` The search query - following the `Log search syntax <https://docs.datadoghq.com/logs/search_syntax/>`_.
        * ``rollup_method`` The stats roll-up method - supports ``count`` , ``avg`` , and ``cardinality``.
        * ``measure`` For ``avg`` and cardinality ``rollup_method`` - specify the measure or the facet name you want to use.
        * ``time_window`` #m (between 1 and 2880), #h (between 1 and 48).
        * ``operator`` ``<`` , ``<=`` , ``>`` , ``>=`` , ``==`` , or ``!=``.
        * ``#`` an integer or decimal number used to set the threshold.

        **NOTE** CI Pipeline monitors are in alpha on US1, EU, US3 and US5.

        **CI Tests Alert Query**

        Example: ``ci-tests(query).rollup(rollup_method[, measure]).last(time_window) operator #``

        * ``query`` The search query - following the `Log search syntax <https://docs.datadoghq.com/logs/search_syntax/>`_.
        * ``rollup_method`` The stats roll-up method - supports ``count`` , ``avg`` , and ``cardinality``.
        * ``measure`` For ``avg`` and cardinality ``rollup_method`` - specify the measure or the facet name you want to use.
        * ``time_window`` #m (between 1 and 2880), #h (between 1 and 48).
        * ``operator`` ``<`` , ``<=`` , ``>`` , ``>=`` , ``==`` , or ``!=``.
        * ``#`` an integer or decimal number used to set the threshold.

        **NOTE** CI Test monitors are available only in closed beta on US1, EU, US3 and US5.

        **Error Tracking Alert Query**

        Example(RUM): ``error-tracking-rum(query).rollup(rollup_method[, measure]).last(time_window) operator #``
        Example(APM Traces): ``error-tracking-traces(query).rollup(rollup_method[, measure]).last(time_window) operator #``

        * ``query`` The search query - following the `Log search syntax <https://docs.datadoghq.com/logs/search_syntax/>`_.
        * ``rollup_method`` The stats roll-up method - supports ``count`` , ``avg`` , and ``cardinality``.
        * ``measure`` For ``avg`` and cardinality ``rollup_method`` - specify the measure or the facet name you want to use.
        * ``time_window`` #m (between 1 and 2880), #h (between 1 and 48).
        * ``operator`` ``<`` , ``<=`` , ``>`` , ``>=`` , ``==`` , or ``!=``.
        * ``#`` an integer or decimal number used to set the threshold.

        :param body: Create a monitor request body.
        :type body: Monitor
        :rtype: Monitor
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._create_monitor_endpoint.call_with_http_info(**kwargs)

    def delete_monitor(
        self,
        monitor_id: int,
        *,
        force: Union[str, UnsetType] = unset,
    ) -> DeletedMonitor:
        """Delete a monitor.

        Delete the specified monitor

        :param monitor_id: The ID of the monitor.
        :type monitor_id: int
        :param force: Delete the monitor even if it's referenced by other resources (for example SLO, composite monitor).
        :type force: str, optional
        :rtype: DeletedMonitor
        """
        kwargs: Dict[str, Any] = {}
        kwargs["monitor_id"] = monitor_id

        if force is not unset:
            kwargs["force"] = force

        return self._delete_monitor_endpoint.call_with_http_info(**kwargs)

    def get_monitor(
        self,
        monitor_id: int,
        *,
        group_states: Union[str, UnsetType] = unset,
    ) -> Monitor:
        """Get a monitor's details.

        Get details about the specified monitor from your organization.

        :param monitor_id: The ID of the monitor
        :type monitor_id: int
        :param group_states: When specified, shows additional information about the group states. Choose one or more from ``all`` , ``alert`` , ``warn`` , and ``no data``.
        :type group_states: str, optional
        :rtype: Monitor
        """
        kwargs: Dict[str, Any] = {}
        kwargs["monitor_id"] = monitor_id

        if group_states is not unset:
            kwargs["group_states"] = group_states

        return self._get_monitor_endpoint.call_with_http_info(**kwargs)

    def list_monitors(
        self,
        *,
        group_states: Union[str, UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        tags: Union[str, UnsetType] = unset,
        monitor_tags: Union[str, UnsetType] = unset,
        with_downtimes: Union[bool, UnsetType] = unset,
        id_offset: Union[int, UnsetType] = unset,
        page: Union[int, UnsetType] = unset,
        page_size: Union[int, UnsetType] = unset,
    ) -> List[Monitor]:
        """Get all monitor details.

        Get details about the specified monitor from your organization.

        :param group_states: When specified, shows additional information about the group states.
            Choose one or more from ``all`` , ``alert`` , ``warn`` , and ``no data``.
        :type group_states: str, optional
        :param name: A string to filter monitors by name.
        :type name: str, optional
        :param tags: A comma separated list indicating what tags, if any, should be used to filter the list of monitors by scope.
            For example, ``host:host0``.
        :type tags: str, optional
        :param monitor_tags: A comma separated list indicating what service and/or custom tags, if any, should be used to filter the list of monitors.
            Tags created in the Datadog UI automatically have the service key prepended. For example, ``service:my-app``.
        :type monitor_tags: str, optional
        :param with_downtimes: If this argument is set to true, then the returned data includes all current active downtimes for each monitor.
        :type with_downtimes: bool, optional
        :param id_offset: Use this parameter for paginating through large sets of monitors. Start with a value of zero, make a request, set the value to the last ID of result set, and then repeat until the response is empty.
        :type id_offset: int, optional
        :param page: The page to start paginating from. If this argument is not specified, the request returns all monitors without pagination.
        :type page: int, optional
        :param page_size: The number of monitors to return per page. If the page argument is not specified, the default behavior returns all monitors without a ``page_size`` limit. However, if page is specified and ``page_size`` is not, the argument defaults to 100.
        :type page_size: int, optional
        :rtype: [Monitor]
        """
        kwargs: Dict[str, Any] = {}
        if group_states is not unset:
            kwargs["group_states"] = group_states

        if name is not unset:
            kwargs["name"] = name

        if tags is not unset:
            kwargs["tags"] = tags

        if monitor_tags is not unset:
            kwargs["monitor_tags"] = monitor_tags

        if with_downtimes is not unset:
            kwargs["with_downtimes"] = with_downtimes

        if id_offset is not unset:
            kwargs["id_offset"] = id_offset

        if page is not unset:
            kwargs["page"] = page

        if page_size is not unset:
            kwargs["page_size"] = page_size

        return self._list_monitors_endpoint.call_with_http_info(**kwargs)

    def search_monitor_groups(
        self,
        *,
        query: Union[str, UnsetType] = unset,
        page: Union[int, UnsetType] = unset,
        per_page: Union[int, UnsetType] = unset,
        sort: Union[str, UnsetType] = unset,
    ) -> MonitorGroupSearchResponse:
        """Monitors group search.

        Search and filter your monitor groups details.

        :param query: After entering a search query in your `Manage Monitor page <https://app.datadoghq.com/monitors/manage>`_ use the query parameter value in the
            URL of the page as value for this parameter. Consult the dedicated `manage monitor documentation </monitors/manage/#find-the-monitors>`_
            page to learn more.

            The query can contain any number of space-separated monitor attributes, for instance ``query="type:metric status:alert"``.
        :type query: str, optional
        :param page: Page to start paginating from.
        :type page: int, optional
        :param per_page: Number of monitors to return per page.
        :type per_page: int, optional
        :param sort: String for sort order, composed of field and sort order separate by a comma, for example ``name,asc``. Supported sort directions: ``asc`` , ``desc``. Supported fields:

            * ``name``
            * ``status``
            * ``tags``
        :type sort: str, optional
        :rtype: MonitorGroupSearchResponse
        """
        kwargs: Dict[str, Any] = {}
        if query is not unset:
            kwargs["query"] = query

        if page is not unset:
            kwargs["page"] = page

        if per_page is not unset:
            kwargs["per_page"] = per_page

        if sort is not unset:
            kwargs["sort"] = sort

        return self._search_monitor_groups_endpoint.call_with_http_info(**kwargs)

    def search_monitors(
        self,
        *,
        query: Union[str, UnsetType] = unset,
        page: Union[int, UnsetType] = unset,
        per_page: Union[int, UnsetType] = unset,
        sort: Union[str, UnsetType] = unset,
    ) -> MonitorSearchResponse:
        """Monitors search.

        Search and filter your monitors details.

        :param query: After entering a search query in your `Manage Monitor page <https://app.datadoghq.com/monitors/manage>`_ use the query parameter value in the
            URL of the page as value for this parameter. Consult the dedicated `manage monitor documentation </monitors/manage/#find-the-monitors>`_
            page to learn more.

            The query can contain any number of space-separated monitor attributes, for instance ``query="type:metric status:alert"``.
        :type query: str, optional
        :param page: Page to start paginating from.
        :type page: int, optional
        :param per_page: Number of monitors to return per page.
        :type per_page: int, optional
        :param sort: String for sort order, composed of field and sort order separate by a comma, for example ``name,asc``. Supported sort directions: ``asc`` , ``desc``. Supported fields:

            * ``name``
            * ``status``
            * ``tags``
        :type sort: str, optional
        :rtype: MonitorSearchResponse
        """
        kwargs: Dict[str, Any] = {}
        if query is not unset:
            kwargs["query"] = query

        if page is not unset:
            kwargs["page"] = page

        if per_page is not unset:
            kwargs["per_page"] = per_page

        if sort is not unset:
            kwargs["sort"] = sort

        return self._search_monitors_endpoint.call_with_http_info(**kwargs)

    def update_monitor(
        self,
        monitor_id: int,
        body: MonitorUpdateRequest,
    ) -> Monitor:
        """Edit a monitor.

        Edit the specified monitor.

        :param monitor_id: The ID of the monitor.
        :type monitor_id: int
        :param body: Edit a monitor request body.
        :type body: MonitorUpdateRequest
        :rtype: Monitor
        """
        kwargs: Dict[str, Any] = {}
        kwargs["monitor_id"] = monitor_id

        kwargs["body"] = body

        return self._update_monitor_endpoint.call_with_http_info(**kwargs)

    def validate_existing_monitor(
        self,
        monitor_id: int,
        body: Monitor,
    ) -> dict:
        """Validate an existing monitor.

        Validate the monitor provided in the request.

        :param monitor_id: The ID of the monitor
        :type monitor_id: int
        :param body: Monitor request object
        :type body: Monitor
        :rtype: dict
        """
        kwargs: Dict[str, Any] = {}
        kwargs["monitor_id"] = monitor_id

        kwargs["body"] = body

        return self._validate_existing_monitor_endpoint.call_with_http_info(**kwargs)

    def validate_monitor(
        self,
        body: Monitor,
    ) -> dict:
        """Validate a monitor.

        Validate the monitor provided in the request.

        :param body: Monitor request object
        :type body: Monitor
        :rtype: dict
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._validate_monitor_endpoint.call_with_http_info(**kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelComposed,
    cached_property,
)


class SecurityMonitoringRuleQuery(ModelComposed):
    def __init__(self, **kwargs):
        """
        Query for matching rule.

        :param aggregation: The aggregation type.
        :type aggregation: SecurityMonitoringRuleQueryAggregation, optional

        :param distinct_fields: Field for which the cardinality is measured. Sent as an array.
        :type distinct_fields: [str], optional

        :param group_by_fields: Fields to group by.
        :type group_by_fields: [str], optional

        :param metric: (Deprecated) The target field to aggregate over when using the sum or max
            aggregations. `metrics` field should be used instead.
        :type metric: str, optional

        :param metrics: Group of target fields to aggregate over when using the sum, max, geo data, or new value aggregations. The sum, max, and geo data aggregations only accept one value in this list, whereas the new value aggregation accepts up to five values.
        :type metrics: [str], optional

        :param name: Name of the query.
        :type name: str, optional

        :param query: Query to run on logs.
        :type query: str

        :param correlated_by_fields: Fields to group by.
        :type correlated_by_fields: [str], optional

        :param correlated_query_index: Index of the rule query used to retrieve the correlated field.
        :type correlated_query_index: int, optional

        :param rule_id: Rule ID to match on signals.
        :type rule_id: str
        """
        super().__init__(kwargs)

    @cached_property
    def _composed_schemas(_):
        # we need this here to make our import statements work
        # we must store _composed_schemas in here so the code is only run
        # when we invoke this method. If we kept this at the class
        # level we would get an error because the class level
        # code would be run when this module is imported, and these composed
        # classes don't exist yet because their module has not finished
        # loading
        from datadog_api_client.v2.model.security_monitoring_standard_rule_query import (
            SecurityMonitoringStandardRuleQuery,
        )
        from datadog_api_client.v2.model.security_monitoring_signal_rule_query import SecurityMonitoringSignalRuleQuery

        return {
            "oneOf": [
                SecurityMonitoringStandardRuleQuery,
                SecurityMonitoringSignalRuleQuery,
            ],
        }



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Dict, Union

from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
from datadog_api_client.model_utils import (
    UnsetType,
    unset,
)
from datadog_api_client.v1.model.slo_correction_list_response import SLOCorrectionListResponse
from datadog_api_client.v1.model.slo_correction_response import SLOCorrectionResponse
from datadog_api_client.v1.model.slo_correction_create_request import SLOCorrectionCreateRequest
from datadog_api_client.v1.model.slo_correction_update_request import SLOCorrectionUpdateRequest


class ServiceLevelObjectiveCorrectionsApi:
    """
    SLO Status Corrections allow you to prevent specific time periods from negatively impacting
    your SLO’s status and error budget. You can use Status Corrections for various purposes, such
    as removing planned maintenance windows, non-business hours, or other time periods that do
    not correspond to genuine issues.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self._create_slo_correction_endpoint = _Endpoint(
            settings={
                "response_type": (SLOCorrectionResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/slo/correction",
                "operation_id": "create_slo_correction",
                "http_method": "POST",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (SLOCorrectionCreateRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._delete_slo_correction_endpoint = _Endpoint(
            settings={
                "response_type": None,
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/slo/correction/{slo_correction_id}",
                "operation_id": "delete_slo_correction",
                "http_method": "DELETE",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "slo_correction_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "slo_correction_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["*/*"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._get_slo_correction_endpoint = _Endpoint(
            settings={
                "response_type": (SLOCorrectionResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/slo/correction/{slo_correction_id}",
                "operation_id": "get_slo_correction",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "slo_correction_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "slo_correction_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._list_slo_correction_endpoint = _Endpoint(
            settings={
                "response_type": (SLOCorrectionListResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/slo/correction",
                "operation_id": "list_slo_correction",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "offset": {
                    "openapi_types": (int,),
                    "attribute": "offset",
                    "location": "query",
                },
                "limit": {
                    "openapi_types": (int,),
                    "attribute": "limit",
                    "location": "query",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._update_slo_correction_endpoint = _Endpoint(
            settings={
                "response_type": (SLOCorrectionResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/slo/correction/{slo_correction_id}",
                "operation_id": "update_slo_correction",
                "http_method": "PATCH",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "slo_correction_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "slo_correction_id",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (SLOCorrectionUpdateRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

    def create_slo_correction(
        self,
        body: SLOCorrectionCreateRequest,
    ) -> SLOCorrectionResponse:
        """Create an SLO correction.

        Create an SLO Correction.

        :param body: Create an SLO Correction
        :type body: SLOCorrectionCreateRequest
        :rtype: SLOCorrectionResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._create_slo_correction_endpoint.call_with_http_info(**kwargs)

    def delete_slo_correction(
        self,
        slo_correction_id: str,
    ) -> None:
        """Delete an SLO correction.

        Permanently delete the specified SLO correction object.

        :param slo_correction_id: The ID of the SLO correction object.
        :type slo_correction_id: str
        :rtype: None
        """
        kwargs: Dict[str, Any] = {}
        kwargs["slo_correction_id"] = slo_correction_id

        return self._delete_slo_correction_endpoint.call_with_http_info(**kwargs)

    def get_slo_correction(
        self,
        slo_correction_id: str,
    ) -> SLOCorrectionResponse:
        """Get an SLO correction for an SLO.

        Get an SLO correction.

        :param slo_correction_id: The ID of the SLO correction object.
        :type slo_correction_id: str
        :rtype: SLOCorrectionResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["slo_correction_id"] = slo_correction_id

        return self._get_slo_correction_endpoint.call_with_http_info(**kwargs)

    def list_slo_correction(
        self,
        *,
        offset: Union[int, UnsetType] = unset,
        limit: Union[int, UnsetType] = unset,
    ) -> SLOCorrectionListResponse:
        """Get all SLO corrections.

        Get all Service Level Objective corrections.

        :param offset: The specific offset to use as the beginning of the returned response.
        :type offset: int, optional
        :param limit: The number of SLO corrections to return in the response. Default is 25.
        :type limit: int, optional
        :rtype: SLOCorrectionListResponse
        """
        kwargs: Dict[str, Any] = {}
        if offset is not unset:
            kwargs["offset"] = offset

        if limit is not unset:
            kwargs["limit"] = limit

        return self._list_slo_correction_endpoint.call_with_http_info(**kwargs)

    def update_slo_correction(
        self,
        slo_correction_id: str,
        body: SLOCorrectionUpdateRequest,
    ) -> SLOCorrectionResponse:
        """Update an SLO correction.

        Update the specified SLO correction object.

        :param slo_correction_id: The ID of the SLO correction object.
        :type slo_correction_id: str
        :param body: The edited SLO correction object.
        :type body: SLOCorrectionUpdateRequest
        :rtype: SLOCorrectionResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["slo_correction_id"] = slo_correction_id

        kwargs["body"] = body

        return self._update_slo_correction_endpoint.call_with_http_info(**kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    none_type,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.search_slo_timeframe import SearchSLOTimeframe


class SearchSLOThreshold(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.search_slo_timeframe import SearchSLOTimeframe

        return {
            "target": (float,),
            "target_display": (str,),
            "timeframe": (SearchSLOTimeframe,),
            "warning": (float, none_type),
            "warning_display": (str, none_type),
        }

    attribute_map = {
        "target": "target",
        "target_display": "target_display",
        "timeframe": "timeframe",
        "warning": "warning",
        "warning_display": "warning_display",
    }

    def __init__(
        self_,
        target: float,
        timeframe: SearchSLOTimeframe,
        target_display: Union[str, UnsetType] = unset,
        warning: Union[float, none_type, UnsetType] = unset,
        warning_display: Union[str, none_type, UnsetType] = unset,
        **kwargs,
    ):
        """
        SLO thresholds (target and optionally warning) for a single time window.

        :param target: The target value for the service level indicator within the corresponding
            timeframe.
        :type target: float

        :param target_display: A string representation of the target that indicates its precision.
            It uses trailing zeros to show significant decimal places (for example ``98.00`` ).

            Always included in service level objective responses. Ignored in
            create/update requests.
        :type target_display: str, optional

        :param timeframe: The SLO time window options.
        :type timeframe: SearchSLOTimeframe

        :param warning: The warning value for the service level objective.
        :type warning: float, none_type, optional

        :param warning_display: A string representation of the warning target (see the description of
            the ``target_display`` field for details).

            Included in service level objective responses if a warning target exists.
            Ignored in create/update requests.
        :type warning_display: str, none_type, optional
        """
        if target_display is not unset:
            kwargs["target_display"] = target_display
        if warning is not unset:
            kwargs["warning"] = warning
        if warning_display is not unset:
            kwargs["warning_display"] = warning_display
        super().__init__(kwargs)

        self_.target = target
        self_.timeframe = timeframe



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.api_key import ApiKey
    from datadog_api_client.v1.model.application_key import ApplicationKey
    from datadog_api_client.v1.model.organization import Organization
    from datadog_api_client.v1.model.user import User


class OrganizationCreateResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.api_key import ApiKey
        from datadog_api_client.v1.model.application_key import ApplicationKey
        from datadog_api_client.v1.model.organization import Organization
        from datadog_api_client.v1.model.user import User

        return {
            "api_key": (ApiKey,),
            "application_key": (ApplicationKey,),
            "org": (Organization,),
            "user": (User,),
        }

    attribute_map = {
        "api_key": "api_key",
        "application_key": "application_key",
        "org": "org",
        "user": "user",
    }

    def __init__(
        self_,
        api_key: Union[ApiKey, UnsetType] = unset,
        application_key: Union[ApplicationKey, UnsetType] = unset,
        org: Union[Organization, UnsetType] = unset,
        user: Union[User, UnsetType] = unset,
        **kwargs,
    ):
        """
        Response object for an organization creation.

        :param api_key: Datadog API key.
        :type api_key: ApiKey, optional

        :param application_key: An application key with its associated metadata.
        :type application_key: ApplicationKey, optional

        :param org: Create, edit, and manage organizations.
        :type org: Organization, optional

        :param user: Create, edit, and disable users.
        :type user: User, optional
        """
        if api_key is not unset:
            kwargs["api_key"] = api_key
        if application_key is not unset:
            kwargs["application_key"] = application_key
        if org is not unset:
            kwargs["org"] = org
        if user is not unset:
            kwargs["user"] = user
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Dict

from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
from datadog_api_client.v1.model.dashboard_list_list_response import DashboardListListResponse
from datadog_api_client.v1.model.dashboard_list import DashboardList
from datadog_api_client.v1.model.dashboard_list_delete_response import DashboardListDeleteResponse


class DashboardListsApi:
    """
    Interact with your dashboard lists through the API to
    organize, find, and share all of your dashboards with your team and
    organization.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self._create_dashboard_list_endpoint = _Endpoint(
            settings={
                "response_type": (DashboardList,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/dashboard/lists/manual",
                "operation_id": "create_dashboard_list",
                "http_method": "POST",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (DashboardList,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._delete_dashboard_list_endpoint = _Endpoint(
            settings={
                "response_type": (DashboardListDeleteResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/dashboard/lists/manual/{list_id}",
                "operation_id": "delete_dashboard_list",
                "http_method": "DELETE",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "list_id": {
                    "required": True,
                    "openapi_types": (int,),
                    "attribute": "list_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._get_dashboard_list_endpoint = _Endpoint(
            settings={
                "response_type": (DashboardList,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/dashboard/lists/manual/{list_id}",
                "operation_id": "get_dashboard_list",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "list_id": {
                    "required": True,
                    "openapi_types": (int,),
                    "attribute": "list_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._list_dashboard_lists_endpoint = _Endpoint(
            settings={
                "response_type": (DashboardListListResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/dashboard/lists/manual",
                "operation_id": "list_dashboard_lists",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={},
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._update_dashboard_list_endpoint = _Endpoint(
            settings={
                "response_type": (DashboardList,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/dashboard/lists/manual/{list_id}",
                "operation_id": "update_dashboard_list",
                "http_method": "PUT",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "list_id": {
                    "required": True,
                    "openapi_types": (int,),
                    "attribute": "list_id",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (DashboardList,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

    def create_dashboard_list(
        self,
        body: DashboardList,
    ) -> DashboardList:
        """Create a dashboard list.

        Create an empty dashboard list.

        :param body: Create a dashboard list request body.
        :type body: DashboardList
        :rtype: DashboardList
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._create_dashboard_list_endpoint.call_with_http_info(**kwargs)

    def delete_dashboard_list(
        self,
        list_id: int,
    ) -> DashboardListDeleteResponse:
        """Delete a dashboard list.

        Delete a dashboard list.

        :param list_id: ID of the dashboard list to delete.
        :type list_id: int
        :rtype: DashboardListDeleteResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["list_id"] = list_id

        return self._delete_dashboard_list_endpoint.call_with_http_info(**kwargs)

    def get_dashboard_list(
        self,
        list_id: int,
    ) -> DashboardList:
        """Get a dashboard list.

        Fetch an existing dashboard list's definition.

        :param list_id: ID of the dashboard list to fetch.
        :type list_id: int
        :rtype: DashboardList
        """
        kwargs: Dict[str, Any] = {}
        kwargs["list_id"] = list_id

        return self._get_dashboard_list_endpoint.call_with_http_info(**kwargs)

    def list_dashboard_lists(
        self,
    ) -> DashboardListListResponse:
        """Get all dashboard lists.

        Fetch all of your existing dashboard list definitions.

        :rtype: DashboardListListResponse
        """
        kwargs: Dict[str, Any] = {}
        return self._list_dashboard_lists_endpoint.call_with_http_info(**kwargs)

    def update_dashboard_list(
        self,
        list_id: int,
        body: DashboardList,
    ) -> DashboardList:
        """Update a dashboard list.

        Update the name of a dashboard list.

        :param list_id: ID of the dashboard list to update.
        :type list_id: int
        :param body: Update a dashboard list request body.
        :type body: DashboardList
        :rtype: DashboardList
        """
        kwargs: Dict[str, Any] = {}
        kwargs["list_id"] = list_id

        kwargs["body"] = body

        return self._update_dashboard_list_endpoint.call_with_http_info(**kwargs)



"""
Submit metrics with compression returns "Payload accepted" response
"""

from datetime import datetime
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.metrics_api import MetricsApi
from datadog_api_client.v2.model.metric_content_encoding import MetricContentEncoding
from datadog_api_client.v2.model.metric_intake_type import MetricIntakeType
from datadog_api_client.v2.model.metric_payload import MetricPayload
from datadog_api_client.v2.model.metric_point import MetricPoint
from datadog_api_client.v2.model.metric_series import MetricSeries

body = MetricPayload(
    series=[
        MetricSeries(
            metric="system.load.1",
            type=MetricIntakeType.UNSPECIFIED,
            points=[
                MetricPoint(
                    timestamp=int(datetime.now().timestamp()),
                    value=0.7,
                ),
            ],
        ),
    ],
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = MetricsApi(api_client)
    response = api_instance.submit_metrics(content_encoding=MetricContentEncoding.ZSTD1, body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.metric_series import MetricSeries


class MetricPayload(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.metric_series import MetricSeries

        return {
            "series": ([MetricSeries],),
        }

    attribute_map = {
        "series": "series",
    }

    def __init__(self_, series: List[MetricSeries], **kwargs):
        """
        The metrics' payload.

        :param series: A list of time series to submit to Datadog.
        :type series: [MetricSeries]
        """
        super().__init__(kwargs)

        self_.series = series



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class RUMApplicationListAttributes(ModelNormal):
    validations = {
        "org_id": {
            "inclusive_maximum": 2147483647,
        },
    }

    @cached_property
    def openapi_types(_):
        return {
            "application_id": (str,),
            "created_at": (int,),
            "created_by_handle": (str,),
            "hash": (str,),
            "is_active": (bool,),
            "name": (str,),
            "org_id": (int,),
            "type": (str,),
            "updated_at": (int,),
            "updated_by_handle": (str,),
        }

    attribute_map = {
        "application_id": "application_id",
        "created_at": "created_at",
        "created_by_handle": "created_by_handle",
        "hash": "hash",
        "is_active": "is_active",
        "name": "name",
        "org_id": "org_id",
        "type": "type",
        "updated_at": "updated_at",
        "updated_by_handle": "updated_by_handle",
    }

    def __init__(
        self_,
        application_id: str,
        created_at: int,
        created_by_handle: str,
        name: str,
        org_id: int,
        type: str,
        updated_at: int,
        updated_by_handle: str,
        hash: Union[str, UnsetType] = unset,
        is_active: Union[bool, UnsetType] = unset,
        **kwargs,
    ):
        """
        RUM application list attributes.

        :param application_id: ID of the RUM application.
        :type application_id: str

        :param created_at: Timestamp in ms of the creation date.
        :type created_at: int

        :param created_by_handle: Handle of the creator user.
        :type created_by_handle: str

        :param hash: Hash of the RUM application. Optional.
        :type hash: str, optional

        :param is_active: Indicates if the RUM application is active.
        :type is_active: bool, optional

        :param name: Name of the RUM application.
        :type name: str

        :param org_id: Org ID of the RUM application.
        :type org_id: int

        :param type: Type of the RUM application. Supported values are ``browser`` , ``ios`` , ``android`` , ``react-native`` , ``flutter``.
        :type type: str

        :param updated_at: Timestamp in ms of the last update date.
        :type updated_at: int

        :param updated_by_handle: Handle of the updater user.
        :type updated_by_handle: str
        """
        if hash is not unset:
            kwargs["hash"] = hash
        if is_active is not unset:
            kwargs["is_active"] = is_active
        super().__init__(kwargs)

        self_.application_id = application_id
        self_.created_at = created_at
        self_.created_by_handle = created_by_handle
        self_.name = name
        self_.org_id = org_id
        self_.type = type
        self_.updated_at = updated_at
        self_.updated_by_handle = updated_by_handle



"""
Delete a dashboard returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.dashboards_api import DashboardsApi

# there is a valid "dashboard" in the system
DASHBOARD_ID = environ["DASHBOARD_ID"]

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = DashboardsApi(api_client)
    response = api_instance.delete_dashboard(
        dashboard_id=DASHBOARD_ID,
    )

    print(response)



"""
Get incident attachments returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.incidents_api import IncidentsApi

# there is a valid "incident" in the system
INCIDENT_DATA_ID = environ["INCIDENT_DATA_ID"]

configuration = Configuration()
configuration.unstable_operations["list_incident_attachments"] = True
with ApiClient(configuration) as api_client:
    api_instance = IncidentsApi(api_client)
    response = api_instance.list_incident_attachments(
        incident_id=INCIDENT_DATA_ID,
    )

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.formula_and_function_apm_dependency_stats_data_source import (
        FormulaAndFunctionApmDependencyStatsDataSource,
    )
    from datadog_api_client.v1.model.formula_and_function_apm_dependency_stat_name import (
        FormulaAndFunctionApmDependencyStatName,
    )


class FormulaAndFunctionApmDependencyStatsQueryDefinition(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.formula_and_function_apm_dependency_stats_data_source import (
            FormulaAndFunctionApmDependencyStatsDataSource,
        )
        from datadog_api_client.v1.model.formula_and_function_apm_dependency_stat_name import (
            FormulaAndFunctionApmDependencyStatName,
        )

        return {
            "data_source": (FormulaAndFunctionApmDependencyStatsDataSource,),
            "env": (str,),
            "is_upstream": (bool,),
            "name": (str,),
            "operation_name": (str,),
            "primary_tag_name": (str,),
            "primary_tag_value": (str,),
            "resource_name": (str,),
            "service": (str,),
            "stat": (FormulaAndFunctionApmDependencyStatName,),
        }

    attribute_map = {
        "data_source": "data_source",
        "env": "env",
        "is_upstream": "is_upstream",
        "name": "name",
        "operation_name": "operation_name",
        "primary_tag_name": "primary_tag_name",
        "primary_tag_value": "primary_tag_value",
        "resource_name": "resource_name",
        "service": "service",
        "stat": "stat",
    }

    def __init__(
        self_,
        data_source: FormulaAndFunctionApmDependencyStatsDataSource,
        env: str,
        name: str,
        operation_name: str,
        resource_name: str,
        service: str,
        stat: FormulaAndFunctionApmDependencyStatName,
        is_upstream: Union[bool, UnsetType] = unset,
        primary_tag_name: Union[str, UnsetType] = unset,
        primary_tag_value: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        A formula and functions APM dependency stats query.

        :param data_source: Data source for APM dependency stats queries.
        :type data_source: FormulaAndFunctionApmDependencyStatsDataSource

        :param env: APM environment.
        :type env: str

        :param is_upstream: Determines whether stats for upstream or downstream dependencies should be queried.
        :type is_upstream: bool, optional

        :param name: Name of query to use in formulas.
        :type name: str

        :param operation_name: Name of operation on service.
        :type operation_name: str

        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog.
        :type primary_tag_name: str, optional

        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified.
        :type primary_tag_value: str, optional

        :param resource_name: APM resource.
        :type resource_name: str

        :param service: APM service.
        :type service: str

        :param stat: APM statistic.
        :type stat: FormulaAndFunctionApmDependencyStatName
        """
        if is_upstream is not unset:
            kwargs["is_upstream"] = is_upstream
        if primary_tag_name is not unset:
            kwargs["primary_tag_name"] = primary_tag_name
        if primary_tag_value is not unset:
            kwargs["primary_tag_value"] = primary_tag_value
        super().__init__(kwargs)

        self_.data_source = data_source
        self_.env = env
        self_.name = name
        self_.operation_name = operation_name
        self_.resource_name = resource_name
        self_.service = service
        self_.stat = stat



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class MonitorOverallStates(ModelSimple):
    """
    The different states your monitor can be in.

    :param value: Must be one of ["Alert", "Ignored", "No Data", "OK", "Skipped", "Unknown", "Warn"].
    :type value: str
    """

    allowed_values = {
        "Alert",
        "Ignored",
        "No Data",
        "OK",
        "Skipped",
        "Unknown",
        "Warn",
    }
    ALERT: ClassVar["MonitorOverallStates"]
    IGNORED: ClassVar["MonitorOverallStates"]
    NO_DATA: ClassVar["MonitorOverallStates"]
    OK: ClassVar["MonitorOverallStates"]
    SKIPPED: ClassVar["MonitorOverallStates"]
    UNKNOWN: ClassVar["MonitorOverallStates"]
    WARN: ClassVar["MonitorOverallStates"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


MonitorOverallStates.ALERT = MonitorOverallStates("Alert")
MonitorOverallStates.IGNORED = MonitorOverallStates("Ignored")
MonitorOverallStates.NO_DATA = MonitorOverallStates("No Data")
MonitorOverallStates.OK = MonitorOverallStates("OK")
MonitorOverallStates.SKIPPED = MonitorOverallStates("Skipped")
MonitorOverallStates.UNKNOWN = MonitorOverallStates("Unknown")
MonitorOverallStates.WARN = MonitorOverallStates("Warn")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.access_role import AccessRole


class User(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.access_role import AccessRole

        return {
            "access_role": (AccessRole,),
            "disabled": (bool,),
            "email": (str,),
            "handle": (str,),
            "icon": (str,),
            "name": (str,),
            "verified": (bool,),
        }

    attribute_map = {
        "access_role": "access_role",
        "disabled": "disabled",
        "email": "email",
        "handle": "handle",
        "icon": "icon",
        "name": "name",
        "verified": "verified",
    }
    read_only_vars = {
        "icon",
        "verified",
    }

    def __init__(
        self_,
        access_role: Union[AccessRole, UnsetType] = unset,
        disabled: Union[bool, UnsetType] = unset,
        email: Union[str, UnsetType] = unset,
        handle: Union[str, UnsetType] = unset,
        icon: Union[str, UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        verified: Union[bool, UnsetType] = unset,
        **kwargs,
    ):
        """
        Create, edit, and disable users.

        :param access_role: The access role of the user. Options are **st** (standard user), **adm** (admin user), or **ro** (read-only user).
        :type access_role: AccessRole, optional

        :param disabled: The new disabled status of the user.
        :type disabled: bool, optional

        :param email: The new email of the user.
        :type email: str, optional

        :param handle: The user handle, must be a valid email.
        :type handle: str, optional

        :param icon: Gravatar icon associated to the user.
        :type icon: str, optional

        :param name: The name of the user.
        :type name: str, optional

        :param verified: Whether or not the user logged in Datadog at least once.
        :type verified: bool, optional
        """
        if access_role is not unset:
            kwargs["access_role"] = access_role
        if disabled is not unset:
            kwargs["disabled"] = disabled
        if email is not unset:
            kwargs["email"] = email
        if handle is not unset:
            kwargs["handle"] = handle
        if icon is not unset:
            kwargs["icon"] = icon
        if name is not unset:
            kwargs["name"] = name
        if verified is not unset:
            kwargs["verified"] = verified
        super().__init__(kwargs)



"""
Create an application key with scopes for this service account returns "Created" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.service_accounts_api import ServiceAccountsApi
from datadog_api_client.v2.model.application_key_create_attributes import ApplicationKeyCreateAttributes
from datadog_api_client.v2.model.application_key_create_data import ApplicationKeyCreateData
from datadog_api_client.v2.model.application_key_create_request import ApplicationKeyCreateRequest
from datadog_api_client.v2.model.application_keys_type import ApplicationKeysType

# there is a valid "service_account_user" in the system
SERVICE_ACCOUNT_USER_DATA_ID = environ["SERVICE_ACCOUNT_USER_DATA_ID"]

body = ApplicationKeyCreateRequest(
    data=ApplicationKeyCreateData(
        attributes=ApplicationKeyCreateAttributes(
            name="Example-Create_an_application_key_with_scopes_for_this_service_account_returns_Created_response",
            scopes=[
                "dashboards_read",
                "dashboards_write",
                "dashboards_public_share",
            ],
        ),
        type=ApplicationKeysType.APPLICATION_KEYS,
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = ServiceAccountsApi(api_client)
    response = api_instance.create_service_account_application_key(
        service_account_id=SERVICE_ACCOUNT_USER_DATA_ID, body=body
    )

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Dict, Union

from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
from datadog_api_client.model_utils import (
    UnsetType,
    unset,
)
from datadog_api_client.v1.model.host_mute_response import HostMuteResponse
from datadog_api_client.v1.model.host_mute_settings import HostMuteSettings
from datadog_api_client.v1.model.host_list_response import HostListResponse
from datadog_api_client.v1.model.host_totals import HostTotals


class HostsApi:
    """
    Get information about your live hosts in Datadog.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self._get_host_totals_endpoint = _Endpoint(
            settings={
                "response_type": (HostTotals,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/hosts/totals",
                "operation_id": "get_host_totals",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "_from": {
                    "openapi_types": (int,),
                    "attribute": "from",
                    "location": "query",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._list_hosts_endpoint = _Endpoint(
            settings={
                "response_type": (HostListResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/hosts",
                "operation_id": "list_hosts",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "filter": {
                    "openapi_types": (str,),
                    "attribute": "filter",
                    "location": "query",
                },
                "sort_field": {
                    "openapi_types": (str,),
                    "attribute": "sort_field",
                    "location": "query",
                },
                "sort_dir": {
                    "openapi_types": (str,),
                    "attribute": "sort_dir",
                    "location": "query",
                },
                "start": {
                    "openapi_types": (int,),
                    "attribute": "start",
                    "location": "query",
                },
                "count": {
                    "openapi_types": (int,),
                    "attribute": "count",
                    "location": "query",
                },
                "_from": {
                    "openapi_types": (int,),
                    "attribute": "from",
                    "location": "query",
                },
                "include_muted_hosts_data": {
                    "openapi_types": (bool,),
                    "attribute": "include_muted_hosts_data",
                    "location": "query",
                },
                "include_hosts_metadata": {
                    "openapi_types": (bool,),
                    "attribute": "include_hosts_metadata",
                    "location": "query",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._mute_host_endpoint = _Endpoint(
            settings={
                "response_type": (HostMuteResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/host/{host_name}/mute",
                "operation_id": "mute_host",
                "http_method": "POST",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "host_name": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "host_name",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (HostMuteSettings,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._unmute_host_endpoint = _Endpoint(
            settings={
                "response_type": (HostMuteResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/host/{host_name}/unmute",
                "operation_id": "unmute_host",
                "http_method": "POST",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "host_name": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "host_name",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

    def get_host_totals(
        self,
        *,
        _from: Union[int, UnsetType] = unset,
    ) -> HostTotals:
        """Get the total number of active hosts.

        This endpoint returns the total number of active and up hosts in your Datadog account.
        Active means the host has reported in the past hour, and up means it has reported in the past two hours.

        :param _from: Number of seconds from which you want to get total number of active hosts.
        :type _from: int, optional
        :rtype: HostTotals
        """
        kwargs: Dict[str, Any] = {}
        if _from is not unset:
            kwargs["_from"] = _from

        return self._get_host_totals_endpoint.call_with_http_info(**kwargs)

    def list_hosts(
        self,
        *,
        filter: Union[str, UnsetType] = unset,
        sort_field: Union[str, UnsetType] = unset,
        sort_dir: Union[str, UnsetType] = unset,
        start: Union[int, UnsetType] = unset,
        count: Union[int, UnsetType] = unset,
        _from: Union[int, UnsetType] = unset,
        include_muted_hosts_data: Union[bool, UnsetType] = unset,
        include_hosts_metadata: Union[bool, UnsetType] = unset,
    ) -> HostListResponse:
        """Get all hosts for your organization.

        This endpoint allows searching for hosts by name, alias, or tag.
        Hosts live within the past 3 hours are included by default.
        Retention is 7 days.
        Results are paginated with a max of 1000 results at a time.

        :param filter: String to filter search results.
        :type filter: str, optional
        :param sort_field: Sort hosts by this field.
        :type sort_field: str, optional
        :param sort_dir: Direction of sort. Options include ``asc`` and ``desc``.
        :type sort_dir: str, optional
        :param start: Host result to start search from.
        :type start: int, optional
        :param count: Number of hosts to return. Max 1000.
        :type count: int, optional
        :param _from: Number of seconds since UNIX epoch from which you want to search your hosts.
        :type _from: int, optional
        :param include_muted_hosts_data: Include information on the muted status of hosts and when the mute expires.
        :type include_muted_hosts_data: bool, optional
        :param include_hosts_metadata: Include additional metadata about the hosts (agent_version, machine, platform, processor, etc.).
        :type include_hosts_metadata: bool, optional
        :rtype: HostListResponse
        """
        kwargs: Dict[str, Any] = {}
        if filter is not unset:
            kwargs["filter"] = filter

        if sort_field is not unset:
            kwargs["sort_field"] = sort_field

        if sort_dir is not unset:
            kwargs["sort_dir"] = sort_dir

        if start is not unset:
            kwargs["start"] = start

        if count is not unset:
            kwargs["count"] = count

        if _from is not unset:
            kwargs["_from"] = _from

        if include_muted_hosts_data is not unset:
            kwargs["include_muted_hosts_data"] = include_muted_hosts_data

        if include_hosts_metadata is not unset:
            kwargs["include_hosts_metadata"] = include_hosts_metadata

        return self._list_hosts_endpoint.call_with_http_info(**kwargs)

    def mute_host(
        self,
        host_name: str,
        body: HostMuteSettings,
    ) -> HostMuteResponse:
        """Mute a host.

        Mute a host.

        :param host_name: Name of the host to mute.
        :type host_name: str
        :param body: Mute a host request body.
        :type body: HostMuteSettings
        :rtype: HostMuteResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["host_name"] = host_name

        kwargs["body"] = body

        return self._mute_host_endpoint.call_with_http_info(**kwargs)

    def unmute_host(
        self,
        host_name: str,
    ) -> HostMuteResponse:
        """Unmute a host.

        Unmutes a host. This endpoint takes no JSON arguments.

        :param host_name: Name of the host to unmute.
        :type host_name: str
        :rtype: HostMuteResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["host_name"] = host_name

        return self._unmute_host_endpoint.call_with_http_info(**kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class WidgetHorizontalAlign(ModelSimple):
    """
    Horizontal alignment.

    :param value: Must be one of ["center", "left", "right"].
    :type value: str
    """

    allowed_values = {
        "center",
        "left",
        "right",
    }
    CENTER: ClassVar["WidgetHorizontalAlign"]
    LEFT: ClassVar["WidgetHorizontalAlign"]
    RIGHT: ClassVar["WidgetHorizontalAlign"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


WidgetHorizontalAlign.CENTER = WidgetHorizontalAlign("center")
WidgetHorizontalAlign.LEFT = WidgetHorizontalAlign("left")
WidgetHorizontalAlign.RIGHT = WidgetHorizontalAlign("right")



"""
Get all hosts with metadata for your organization returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.hosts_api import HostsApi

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = HostsApi(api_client)
    response = api_instance.list_hosts(
        include_hosts_metadata=True,
    )

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    none_type,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.slo_raw_error_budget_remaining import SLORawErrorBudgetRemaining
    from datadog_api_client.v1.model.slo_timeframe import SLOTimeframe


class SLOOverallStatuses(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.slo_raw_error_budget_remaining import SLORawErrorBudgetRemaining
        from datadog_api_client.v1.model.slo_timeframe import SLOTimeframe

        return {
            "error": (str, none_type),
            "indexed_at": (int,),
            "raw_error_budget_remaining": (SLORawErrorBudgetRemaining,),
            "span_precision": (int,),
            "status": (float, none_type),
            "target": (float,),
            "timeframe": (SLOTimeframe,),
        }

    attribute_map = {
        "error": "error",
        "indexed_at": "indexed_at",
        "raw_error_budget_remaining": "raw_error_budget_remaining",
        "span_precision": "span_precision",
        "status": "status",
        "target": "target",
        "timeframe": "timeframe",
    }

    def __init__(
        self_,
        error: Union[str, none_type, UnsetType] = unset,
        indexed_at: Union[int, UnsetType] = unset,
        raw_error_budget_remaining: Union[SLORawErrorBudgetRemaining, UnsetType] = unset,
        span_precision: Union[int, UnsetType] = unset,
        status: Union[float, none_type, UnsetType] = unset,
        target: Union[float, UnsetType] = unset,
        timeframe: Union[SLOTimeframe, UnsetType] = unset,
        **kwargs,
    ):
        """
        Overall status of the SLO by timeframes.

        :param error: Error message if SLO status or error budget could not be calculated.
        :type error: str, none_type, optional

        :param indexed_at: timestamp (UNIX time in seconds) of when the SLO status and error budget
            were calculated.
        :type indexed_at: int, optional

        :param raw_error_budget_remaining: Error budget remaining for an SLO.
        :type raw_error_budget_remaining: SLORawErrorBudgetRemaining, optional

        :param span_precision: The amount of decimal places the SLI value is accurate to.
        :type span_precision: int, optional

        :param status: The status of the SLO.
        :type status: float, none_type, optional

        :param target: The target of the SLO.
        :type target: float, optional

        :param timeframe: The SLO time window options.
        :type timeframe: SLOTimeframe, optional
        """
        if error is not unset:
            kwargs["error"] = error
        if indexed_at is not unset:
            kwargs["indexed_at"] = indexed_at
        if raw_error_budget_remaining is not unset:
            kwargs["raw_error_budget_remaining"] = raw_error_budget_remaining
        if span_precision is not unset:
            kwargs["span_precision"] = span_precision
        if status is not unset:
            kwargs["status"] = status
        if target is not unset:
            kwargs["target"] = target
        if timeframe is not unset:
            kwargs["timeframe"] = timeframe
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class TreeMapSizeBy(ModelSimple):
    """
    (deprecated) The attribute formerly used to determine size in the widget.

    :param value: Must be one of ["pct_cpu", "pct_mem"].
    :type value: str
    """

    allowed_values = {
        "pct_cpu",
        "pct_mem",
    }
    PCT_CPU: ClassVar["TreeMapSizeBy"]
    PCT_MEM: ClassVar["TreeMapSizeBy"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


TreeMapSizeBy.PCT_CPU = TreeMapSizeBy("pct_cpu")
TreeMapSizeBy.PCT_MEM = TreeMapSizeBy("pct_mem")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class CheckCanDeleteMonitorResponseData(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "ok": ([int],),
        }

    attribute_map = {
        "ok": "ok",
    }

    def __init__(self_, ok: Union[List[int], UnsetType] = unset, **kwargs):
        """
        Wrapper object with the list of monitor IDs.

        :param ok: An array of of Monitor IDs that can be safely deleted.
        :type ok: [int], optional
        """
        if ok is not unset:
            kwargs["ok"] = ok
        super().__init__(kwargs)



"""
Get a list of security signals returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.security_monitoring_api import SecurityMonitoringApi
from datadog_api_client.v2.model.security_monitoring_signal_list_request import SecurityMonitoringSignalListRequest
from datadog_api_client.v2.model.security_monitoring_signal_list_request_filter import (
    SecurityMonitoringSignalListRequestFilter,
)
from datadog_api_client.v2.model.security_monitoring_signal_list_request_page import (
    SecurityMonitoringSignalListRequestPage,
)
from datadog_api_client.v2.model.security_monitoring_signals_sort import SecurityMonitoringSignalsSort
from datetime import datetime
from dateutil.tz import tzutc

body = SecurityMonitoringSignalListRequest(
    filter=SecurityMonitoringSignalListRequestFilter(
        _from=datetime(2019, 1, 2, 9, 42, 36, 320000, tzinfo=tzutc()),
        query="security:attack status:high",
        to=datetime(2019, 1, 3, 9, 42, 36, 320000, tzinfo=tzutc()),
    ),
    page=SecurityMonitoringSignalListRequestPage(
        cursor="eyJzdGFydEF0IjoiQVFBQUFYS2tMS3pPbm40NGV3QUFBQUJCV0V0clRFdDZVbG8zY3pCRmNsbHJiVmxDWlEifQ==",
        limit=25,
    ),
    sort=SecurityMonitoringSignalsSort.TIMESTAMP_ASCENDING,
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = SecurityMonitoringApi(api_client)
    response = api_instance.search_security_monitoring_signals(body=body)

    print(response)



"""
Aggregate RUM events returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.rum_api import RUMApi
from datadog_api_client.v2.model.rum_aggregate_request import RUMAggregateRequest
from datadog_api_client.v2.model.rum_aggregation_function import RUMAggregationFunction
from datadog_api_client.v2.model.rum_compute import RUMCompute
from datadog_api_client.v2.model.rum_compute_type import RUMComputeType
from datadog_api_client.v2.model.rum_group_by import RUMGroupBy
from datadog_api_client.v2.model.rum_query_filter import RUMQueryFilter
from datadog_api_client.v2.model.rum_query_options import RUMQueryOptions
from datadog_api_client.v2.model.rum_query_page_options import RUMQueryPageOptions

body = RUMAggregateRequest(
    compute=[
        RUMCompute(
            aggregation=RUMAggregationFunction.PERCENTILE_90,
            metric="@view.time_spent",
            type=RUMComputeType.TOTAL,
        ),
    ],
    filter=RUMQueryFilter(
        _from="now-15m",
        query="@type:view AND @session.type:user",
        to="now",
    ),
    group_by=[
        RUMGroupBy(
            facet="@view.time_spent",
            limit=10,
            total=False,
        ),
    ],
    options=RUMQueryOptions(
        timezone="GMT",
    ),
    page=RUMQueryPageOptions(
        limit=25,
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = RUMApi(api_client)
    response = api_instance.aggregate_rum_events(body=body)

    print(response)



"""
Get all security filters returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.security_monitoring_api import SecurityMonitoringApi

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = SecurityMonitoringApi(api_client)
    response = api_instance.list_security_filters()

    print(response)



"""
Get archive order returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.logs_archives_api import LogsArchivesApi

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = LogsArchivesApi(api_client)
    response = api_instance.get_logs_archive_order()

    print(response)



"""
Edit metric metadata returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.metrics_api import MetricsApi
from datadog_api_client.v1.model.metric_metadata import MetricMetadata

body = MetricMetadata(
    per_unit="second",
    type="count",
    unit="byte",
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = MetricsApi(api_client)
    response = api_instance.update_metric_metadata(metric_name="metric_name", body=body)

    print(response)



"""
Delete a single service definition returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.service_definition_api import ServiceDefinitionApi

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = ServiceDefinitionApi(api_client)
    api_instance.delete_service_definition(
        service_name="service-definition-test",
    )



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Dict

from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
from datadog_api_client.v1.model.authentication_validation_response import AuthenticationValidationResponse


class AuthenticationApi:
    """
    All requests to Datadog’s API must be authenticated.
    Requests that write data require reporting access and require an ``API key``.
    Requests that read data require full access and also require an ``application key``.

    **Note:** All Datadog API clients are configured by default to consume Datadog US site APIs.
    If you are on the Datadog EU site, set the environment variable ``DATADOG_HOST`` to
    ``https://api.datadoghq.eu`` or override this value directly when creating your client.

    `Manage your account’s API and application keys <https://app.datadoghq.com/account/settings#api>`_.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self._validate_endpoint = _Endpoint(
            settings={
                "response_type": (AuthenticationValidationResponse,),
                "auth": ["apiKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/validate",
                "operation_id": "validate",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={},
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

    def validate(
        self,
    ) -> AuthenticationValidationResponse:
        """Validate API key.

        Check if the API key (not the APP key) is valid. If invalid, a 403 is returned.

        :rtype: AuthenticationValidationResponse
        """
        kwargs: Dict[str, Any] = {}
        return self._validate_endpoint.call_with_http_info(**kwargs)



"""
Update indexes order returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.logs_indexes_api import LogsIndexesApi
from datadog_api_client.v1.model.logs_indexes_order import LogsIndexesOrder

body = LogsIndexesOrder(
    index_names=[
        "main",
        "payments",
        "web",
    ],
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = LogsIndexesApi(api_client)
    response = api_instance.update_logs_index_order(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.authn_mapping_create_attributes import AuthNMappingCreateAttributes
    from datadog_api_client.v2.model.authn_mapping_create_relationships import AuthNMappingCreateRelationships
    from datadog_api_client.v2.model.authn_mappings_type import AuthNMappingsType


class AuthNMappingCreateData(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.authn_mapping_create_attributes import AuthNMappingCreateAttributes
        from datadog_api_client.v2.model.authn_mapping_create_relationships import AuthNMappingCreateRelationships
        from datadog_api_client.v2.model.authn_mappings_type import AuthNMappingsType

        return {
            "attributes": (AuthNMappingCreateAttributes,),
            "relationships": (AuthNMappingCreateRelationships,),
            "type": (AuthNMappingsType,),
        }

    attribute_map = {
        "attributes": "attributes",
        "relationships": "relationships",
        "type": "type",
    }

    def __init__(
        self_,
        type: AuthNMappingsType,
        attributes: Union[AuthNMappingCreateAttributes, UnsetType] = unset,
        relationships: Union[AuthNMappingCreateRelationships, UnsetType] = unset,
        **kwargs,
    ):
        """
        Data for creating an AuthN Mapping.

        :param attributes: Key/Value pair of attributes used for create request.
        :type attributes: AuthNMappingCreateAttributes, optional

        :param relationships: Relationship of AuthN Mapping create object to Role.
        :type relationships: AuthNMappingCreateRelationships, optional

        :param type: AuthN Mappings resource type.
        :type type: AuthNMappingsType
        """
        if attributes is not unset:
            kwargs["attributes"] = attributes
        if relationships is not unset:
            kwargs["relationships"] = relationships
        super().__init__(kwargs)

        self_.type = type



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


if TYPE_CHECKING:
    pass


class CIAppComputes(ModelNormal):
    @cached_property
    def additional_properties_type(_):
        from datadog_api_client.v2.model.ci_app_aggregate_bucket_value import CIAppAggregateBucketValue

        return (CIAppAggregateBucketValue,)

    def __init__(self_, **kwargs):
        """
        A map of the metric name to value for regular compute, or a list of values for a timeseries.
        """
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.ip_prefixes_agents import IPPrefixesAgents
    from datadog_api_client.v1.model.ip_prefixes_api import IPPrefixesAPI
    from datadog_api_client.v1.model.ip_prefixes_apm import IPPrefixesAPM
    from datadog_api_client.v1.model.ip_prefixes_logs import IPPrefixesLogs
    from datadog_api_client.v1.model.ip_prefixes_process import IPPrefixesProcess
    from datadog_api_client.v1.model.ip_prefixes_synthetics import IPPrefixesSynthetics
    from datadog_api_client.v1.model.ip_prefixes_synthetics_private_locations import (
        IPPrefixesSyntheticsPrivateLocations,
    )
    from datadog_api_client.v1.model.ip_prefixes_webhooks import IPPrefixesWebhooks


class IPRanges(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.ip_prefixes_agents import IPPrefixesAgents
        from datadog_api_client.v1.model.ip_prefixes_api import IPPrefixesAPI
        from datadog_api_client.v1.model.ip_prefixes_apm import IPPrefixesAPM
        from datadog_api_client.v1.model.ip_prefixes_logs import IPPrefixesLogs
        from datadog_api_client.v1.model.ip_prefixes_process import IPPrefixesProcess
        from datadog_api_client.v1.model.ip_prefixes_synthetics import IPPrefixesSynthetics
        from datadog_api_client.v1.model.ip_prefixes_synthetics_private_locations import (
            IPPrefixesSyntheticsPrivateLocations,
        )
        from datadog_api_client.v1.model.ip_prefixes_webhooks import IPPrefixesWebhooks

        return {
            "agents": (IPPrefixesAgents,),
            "api": (IPPrefixesAPI,),
            "apm": (IPPrefixesAPM,),
            "logs": (IPPrefixesLogs,),
            "modified": (str,),
            "process": (IPPrefixesProcess,),
            "synthetics": (IPPrefixesSynthetics,),
            "synthetics_private_locations": (IPPrefixesSyntheticsPrivateLocations,),
            "version": (int,),
            "webhooks": (IPPrefixesWebhooks,),
        }

    attribute_map = {
        "agents": "agents",
        "api": "api",
        "apm": "apm",
        "logs": "logs",
        "modified": "modified",
        "process": "process",
        "synthetics": "synthetics",
        "synthetics_private_locations": "synthetics-private-locations",
        "version": "version",
        "webhooks": "webhooks",
    }

    def __init__(
        self_,
        agents: Union[IPPrefixesAgents, UnsetType] = unset,
        api: Union[IPPrefixesAPI, UnsetType] = unset,
        apm: Union[IPPrefixesAPM, UnsetType] = unset,
        logs: Union[IPPrefixesLogs, UnsetType] = unset,
        modified: Union[str, UnsetType] = unset,
        process: Union[IPPrefixesProcess, UnsetType] = unset,
        synthetics: Union[IPPrefixesSynthetics, UnsetType] = unset,
        synthetics_private_locations: Union[IPPrefixesSyntheticsPrivateLocations, UnsetType] = unset,
        version: Union[int, UnsetType] = unset,
        webhooks: Union[IPPrefixesWebhooks, UnsetType] = unset,
        **kwargs,
    ):
        """
        IP ranges.

        :param agents: Available prefix information for the Agent endpoints.
        :type agents: IPPrefixesAgents, optional

        :param api: Available prefix information for the API endpoints.
        :type api: IPPrefixesAPI, optional

        :param apm: Available prefix information for the APM endpoints.
        :type apm: IPPrefixesAPM, optional

        :param logs: Available prefix information for the Logs endpoints.
        :type logs: IPPrefixesLogs, optional

        :param modified: Date when last updated, in the form ``YYYY-MM-DD-hh-mm-ss``.
        :type modified: str, optional

        :param process: Available prefix information for the Process endpoints.
        :type process: IPPrefixesProcess, optional

        :param synthetics: Available prefix information for the Synthetics endpoints.
        :type synthetics: IPPrefixesSynthetics, optional

        :param synthetics_private_locations: Available prefix information for the Synthetics Private Locations endpoints.
        :type synthetics_private_locations: IPPrefixesSyntheticsPrivateLocations, optional

        :param version: Version of the IP list.
        :type version: int, optional

        :param webhooks: Available prefix information for the Webhook endpoints.
        :type webhooks: IPPrefixesWebhooks, optional
        """
        if agents is not unset:
            kwargs["agents"] = agents
        if api is not unset:
            kwargs["api"] = api
        if apm is not unset:
            kwargs["apm"] = apm
        if logs is not unset:
            kwargs["logs"] = logs
        if modified is not unset:
            kwargs["modified"] = modified
        if process is not unset:
            kwargs["process"] = process
        if synthetics is not unset:
            kwargs["synthetics"] = synthetics
        if synthetics_private_locations is not unset:
            kwargs["synthetics_private_locations"] = synthetics_private_locations
        if version is not unset:
            kwargs["version"] = version
        if webhooks is not unset:
            kwargs["webhooks"] = webhooks
        super().__init__(kwargs)



"""
Create an API test with WEBSOCKET subtype returns "OK - Returns the created test details." response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.synthetics_api import SyntheticsApi
from datadog_api_client.v1.model.synthetics_api_test import SyntheticsAPITest
from datadog_api_client.v1.model.synthetics_api_test_config import SyntheticsAPITestConfig
from datadog_api_client.v1.model.synthetics_api_test_type import SyntheticsAPITestType
from datadog_api_client.v1.model.synthetics_assertion_operator import SyntheticsAssertionOperator
from datadog_api_client.v1.model.synthetics_assertion_target import SyntheticsAssertionTarget
from datadog_api_client.v1.model.synthetics_assertion_type import SyntheticsAssertionType
from datadog_api_client.v1.model.synthetics_test_details_sub_type import SyntheticsTestDetailsSubType
from datadog_api_client.v1.model.synthetics_test_options import SyntheticsTestOptions
from datadog_api_client.v1.model.synthetics_test_options_retry import SyntheticsTestOptionsRetry
from datadog_api_client.v1.model.synthetics_test_request import SyntheticsTestRequest

body = SyntheticsAPITest(
    config=SyntheticsAPITestConfig(
        assertions=[
            SyntheticsAssertionTarget(
                operator=SyntheticsAssertionOperator.IS,
                target="message",
                type=SyntheticsAssertionType.RECEIVED_MESSAGE,
            ),
            SyntheticsAssertionTarget(
                operator=SyntheticsAssertionOperator.LESS_THAN,
                target=2000,
                type=SyntheticsAssertionType.RESPONSE_TIME,
            ),
        ],
        config_variables=[],
        request=SyntheticsTestRequest(
            url="ws://datadoghq.com",
            message="message",
        ),
    ),
    locations=[
        "aws:us-east-2",
    ],
    message="BDD test payload: synthetics_api_test_websocket_payload.json",
    name="Example-Create_an_API_test_with_WEBSOCKET_subtype_returns_OK_Returns_the_created_test_details_response",
    options=SyntheticsTestOptions(
        accept_self_signed=False,
        allow_insecure=True,
        follow_redirects=True,
        min_failure_duration=10,
        min_location_failed=1,
        monitor_name="Example-Create_an_API_test_with_WEBSOCKET_subtype_returns_OK_Returns_the_created_test_details_response",
        monitor_priority=5,
        retry=SyntheticsTestOptionsRetry(
            count=3,
            interval=10.0,
        ),
        tick_every=60,
    ),
    subtype=SyntheticsTestDetailsSubType.WEBSOCKET,
    tags=[
        "testing:api",
    ],
    type=SyntheticsAPITestType.API,
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = SyntheticsApi(api_client)
    response = api_instance.create_synthetics_api_test(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.distribution_point import DistributionPoint
    from datadog_api_client.v1.model.distribution_points_type import DistributionPointsType


class DistributionPointsSeries(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.distribution_point import DistributionPoint
        from datadog_api_client.v1.model.distribution_points_type import DistributionPointsType

        return {
            "host": (str,),
            "metric": (str,),
            "points": ([DistributionPoint],),
            "tags": ([str],),
            "type": (DistributionPointsType,),
        }

    attribute_map = {
        "host": "host",
        "metric": "metric",
        "points": "points",
        "tags": "tags",
        "type": "type",
    }

    def __init__(
        self_,
        metric: str,
        points: List[DistributionPoint],
        host: Union[str, UnsetType] = unset,
        tags: Union[List[str], UnsetType] = unset,
        type: Union[DistributionPointsType, UnsetType] = unset,
        **kwargs,
    ):
        """
        A distribution points metric to submit to Datadog.

        :param host: The name of the host that produced the distribution point metric.
        :type host: str, optional

        :param metric: The name of the distribution points metric.
        :type metric: str

        :param points: Points relating to the distribution point metric. All points must be tuples with timestamp and a list of values (cannot be a string). Timestamps should be in POSIX time in seconds.
        :type points: [DistributionPoint]

        :param tags: A list of tags associated with the distribution point metric.
        :type tags: [str], optional

        :param type: The type of the distribution point.
        :type type: DistributionPointsType, optional
        """
        if host is not unset:
            kwargs["host"] = host
        if tags is not unset:
            kwargs["tags"] = tags
        if type is not unset:
            kwargs["type"] = type
        super().__init__(kwargs)

        self_.metric = metric
        self_.points = points



"""
Trigger tests from CI/CD pipelines returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.synthetics_api import SyntheticsApi
from datadog_api_client.v1.model.synthetics_basic_auth_web import SyntheticsBasicAuthWeb
from datadog_api_client.v1.model.synthetics_basic_auth_web_type import SyntheticsBasicAuthWebType
from datadog_api_client.v1.model.synthetics_ci_batch_metadata import SyntheticsCIBatchMetadata
from datadog_api_client.v1.model.synthetics_ci_batch_metadata_ci import SyntheticsCIBatchMetadataCI
from datadog_api_client.v1.model.synthetics_ci_batch_metadata_git import SyntheticsCIBatchMetadataGit
from datadog_api_client.v1.model.synthetics_ci_batch_metadata_pipeline import SyntheticsCIBatchMetadataPipeline
from datadog_api_client.v1.model.synthetics_ci_batch_metadata_provider import SyntheticsCIBatchMetadataProvider
from datadog_api_client.v1.model.synthetics_ci_test import SyntheticsCITest
from datadog_api_client.v1.model.synthetics_ci_test_body import SyntheticsCITestBody
from datadog_api_client.v1.model.synthetics_device_id import SyntheticsDeviceID
from datadog_api_client.v1.model.synthetics_test_options_retry import SyntheticsTestOptionsRetry

body = SyntheticsCITestBody(
    tests=[
        SyntheticsCITest(
            basic_auth=SyntheticsBasicAuthWeb(
                password="PaSSw0RD!",
                type=SyntheticsBasicAuthWebType.WEB,
                username="my_username",
            ),
            device_ids=[
                SyntheticsDeviceID.LAPTOP_LARGE,
            ],
            locations=[
                "aws:eu-west-3",
            ],
            metadata=SyntheticsCIBatchMetadata(
                ci=SyntheticsCIBatchMetadataCI(
                    pipeline=SyntheticsCIBatchMetadataPipeline(),
                    provider=SyntheticsCIBatchMetadataProvider(),
                ),
                git=SyntheticsCIBatchMetadataGit(),
            ),
            public_id="aaa-aaa-aaa",
            retry=SyntheticsTestOptionsRetry(),
        ),
    ],
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = SyntheticsApi(api_client)
    response = api_instance.trigger_ci_tests(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


class CloudConfigurationRegoRule(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "policy": (str,),
            "resource_types": ([str],),
        }

    attribute_map = {
        "policy": "policy",
        "resource_types": "resourceTypes",
    }

    def __init__(self_, policy: str, resource_types: List[str], **kwargs):
        """
        Rule details.

        :param policy: The policy written in ``rego`` , see: https://www.openpolicyagent.org/docs/latest/policy-language/
        :type policy: str

        :param resource_types: List of resource types that will be evaluated upon. Must have at least one element.
        :type resource_types: [str]
        """
        super().__init__(kwargs)

        self_.policy = policy
        self_.resource_types = resource_types



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Dict, Union

from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
from datadog_api_client.model_utils import (
    UnsetType,
    unset,
)
from datadog_api_client.v1.model.notebooks_response import NotebooksResponse
from datadog_api_client.v1.model.notebook_response import NotebookResponse
from datadog_api_client.v1.model.notebook_create_request import NotebookCreateRequest
from datadog_api_client.v1.model.notebook_update_request import NotebookUpdateRequest


class NotebooksApi:
    """
    Interact with your notebooks through the API to make it easier to organize, find, and
    share all of your notebooks with your team and organization. For more information, see the
    `Notebooks documentation <https://docs.datadoghq.com/notebooks/>`_.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self._create_notebook_endpoint = _Endpoint(
            settings={
                "response_type": (NotebookResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/notebooks",
                "operation_id": "create_notebook",
                "http_method": "POST",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (NotebookCreateRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._delete_notebook_endpoint = _Endpoint(
            settings={
                "response_type": None,
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/notebooks/{notebook_id}",
                "operation_id": "delete_notebook",
                "http_method": "DELETE",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "notebook_id": {
                    "required": True,
                    "openapi_types": (int,),
                    "attribute": "notebook_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["*/*"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._get_notebook_endpoint = _Endpoint(
            settings={
                "response_type": (NotebookResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/notebooks/{notebook_id}",
                "operation_id": "get_notebook",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "notebook_id": {
                    "required": True,
                    "openapi_types": (int,),
                    "attribute": "notebook_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._list_notebooks_endpoint = _Endpoint(
            settings={
                "response_type": (NotebooksResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/notebooks",
                "operation_id": "list_notebooks",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "author_handle": {
                    "openapi_types": (str,),
                    "attribute": "author_handle",
                    "location": "query",
                },
                "exclude_author_handle": {
                    "openapi_types": (str,),
                    "attribute": "exclude_author_handle",
                    "location": "query",
                },
                "start": {
                    "openapi_types": (int,),
                    "attribute": "start",
                    "location": "query",
                },
                "count": {
                    "openapi_types": (int,),
                    "attribute": "count",
                    "location": "query",
                },
                "sort_field": {
                    "openapi_types": (str,),
                    "attribute": "sort_field",
                    "location": "query",
                },
                "sort_dir": {
                    "openapi_types": (str,),
                    "attribute": "sort_dir",
                    "location": "query",
                },
                "query": {
                    "openapi_types": (str,),
                    "attribute": "query",
                    "location": "query",
                },
                "include_cells": {
                    "openapi_types": (bool,),
                    "attribute": "include_cells",
                    "location": "query",
                },
                "is_template": {
                    "openapi_types": (bool,),
                    "attribute": "is_template",
                    "location": "query",
                },
                "type": {
                    "openapi_types": (str,),
                    "attribute": "type",
                    "location": "query",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._update_notebook_endpoint = _Endpoint(
            settings={
                "response_type": (NotebookResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/notebooks/{notebook_id}",
                "operation_id": "update_notebook",
                "http_method": "PUT",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "notebook_id": {
                    "required": True,
                    "openapi_types": (int,),
                    "attribute": "notebook_id",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (NotebookUpdateRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

    def create_notebook(
        self,
        body: NotebookCreateRequest,
    ) -> NotebookResponse:
        """Create a notebook.

        Create a notebook using the specified options.

        :param body: The JSON description of the notebook you want to create.
        :type body: NotebookCreateRequest
        :rtype: NotebookResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._create_notebook_endpoint.call_with_http_info(**kwargs)

    def delete_notebook(
        self,
        notebook_id: int,
    ) -> None:
        """Delete a notebook.

        Delete a notebook using the specified ID.

        :param notebook_id: Unique ID, assigned when you create the notebook.
        :type notebook_id: int
        :rtype: None
        """
        kwargs: Dict[str, Any] = {}
        kwargs["notebook_id"] = notebook_id

        return self._delete_notebook_endpoint.call_with_http_info(**kwargs)

    def get_notebook(
        self,
        notebook_id: int,
    ) -> NotebookResponse:
        """Get a notebook.

        Get a notebook using the specified notebook ID.

        :param notebook_id: Unique ID, assigned when you create the notebook.
        :type notebook_id: int
        :rtype: NotebookResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["notebook_id"] = notebook_id

        return self._get_notebook_endpoint.call_with_http_info(**kwargs)

    def list_notebooks(
        self,
        *,
        author_handle: Union[str, UnsetType] = unset,
        exclude_author_handle: Union[str, UnsetType] = unset,
        start: Union[int, UnsetType] = unset,
        count: Union[int, UnsetType] = unset,
        sort_field: Union[str, UnsetType] = unset,
        sort_dir: Union[str, UnsetType] = unset,
        query: Union[str, UnsetType] = unset,
        include_cells: Union[bool, UnsetType] = unset,
        is_template: Union[bool, UnsetType] = unset,
        type: Union[str, UnsetType] = unset,
    ) -> NotebooksResponse:
        """Get all notebooks.

        Get all notebooks. This can also be used to search for notebooks with a particular ``query`` in the notebook
        ``name`` or author ``handle``.

        :param author_handle: Return notebooks created by the given ``author_handle``.
        :type author_handle: str, optional
        :param exclude_author_handle: Return notebooks not created by the given ``author_handle``.
        :type exclude_author_handle: str, optional
        :param start: The index of the first notebook you want returned.
        :type start: int, optional
        :param count: The number of notebooks to be returned.
        :type count: int, optional
        :param sort_field: Sort by field ``modified`` , ``name`` , or ``created``.
        :type sort_field: str, optional
        :param sort_dir: Sort by direction ``asc`` or ``desc``.
        :type sort_dir: str, optional
        :param query: Return only notebooks with ``query`` string in notebook name or author handle.
        :type query: str, optional
        :param include_cells: Value of ``false`` excludes the ``cells`` and global ``time`` for each notebook.
        :type include_cells: bool, optional
        :param is_template: True value returns only template notebooks. Default is false (returns only non-template notebooks).
        :type is_template: bool, optional
        :param type: If type is provided, returns only notebooks with that metadata type. Default does not have type filtering.
        :type type: str, optional
        :rtype: NotebooksResponse
        """
        kwargs: Dict[str, Any] = {}
        if author_handle is not unset:
            kwargs["author_handle"] = author_handle

        if exclude_author_handle is not unset:
            kwargs["exclude_author_handle"] = exclude_author_handle

        if start is not unset:
            kwargs["start"] = start

        if count is not unset:
            kwargs["count"] = count

        if sort_field is not unset:
            kwargs["sort_field"] = sort_field

        if sort_dir is not unset:
            kwargs["sort_dir"] = sort_dir

        if query is not unset:
            kwargs["query"] = query

        if include_cells is not unset:
            kwargs["include_cells"] = include_cells

        if is_template is not unset:
            kwargs["is_template"] = is_template

        if type is not unset:
            kwargs["type"] = type

        return self._list_notebooks_endpoint.call_with_http_info(**kwargs)

    def update_notebook(
        self,
        notebook_id: int,
        body: NotebookUpdateRequest,
    ) -> NotebookResponse:
        """Update a notebook.

        Update a notebook using the specified ID.

        :param notebook_id: Unique ID, assigned when you create the notebook.
        :type notebook_id: int
        :param body: Update notebook request body.
        :type body: NotebookUpdateRequest
        :rtype: NotebookResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["notebook_id"] = notebook_id

        kwargs["body"] = body

        return self._update_notebook_endpoint.call_with_http_info(**kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    datetime,
    none_type,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.dashboard_layout_type import DashboardLayoutType
    from datadog_api_client.v1.model.dashboard_reflow_type import DashboardReflowType
    from datadog_api_client.v1.model.dashboard_template_variable_preset import DashboardTemplateVariablePreset
    from datadog_api_client.v1.model.dashboard_template_variable import DashboardTemplateVariable
    from datadog_api_client.v1.model.widget import Widget


class Dashboard(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.dashboard_layout_type import DashboardLayoutType
        from datadog_api_client.v1.model.dashboard_reflow_type import DashboardReflowType
        from datadog_api_client.v1.model.dashboard_template_variable_preset import DashboardTemplateVariablePreset
        from datadog_api_client.v1.model.dashboard_template_variable import DashboardTemplateVariable
        from datadog_api_client.v1.model.widget import Widget

        return {
            "author_handle": (str,),
            "author_name": (str, none_type),
            "created_at": (datetime,),
            "description": (str, none_type),
            "id": (str,),
            "is_read_only": (bool,),
            "layout_type": (DashboardLayoutType,),
            "modified_at": (datetime,),
            "notify_list": ([str], none_type),
            "reflow_type": (DashboardReflowType,),
            "restricted_roles": ([str],),
            "template_variable_presets": ([DashboardTemplateVariablePreset], none_type),
            "template_variables": ([DashboardTemplateVariable], none_type),
            "title": (str,),
            "url": (str,),
            "widgets": ([Widget],),
        }

    attribute_map = {
        "author_handle": "author_handle",
        "author_name": "author_name",
        "created_at": "created_at",
        "description": "description",
        "id": "id",
        "is_read_only": "is_read_only",
        "layout_type": "layout_type",
        "modified_at": "modified_at",
        "notify_list": "notify_list",
        "reflow_type": "reflow_type",
        "restricted_roles": "restricted_roles",
        "template_variable_presets": "template_variable_presets",
        "template_variables": "template_variables",
        "title": "title",
        "url": "url",
        "widgets": "widgets",
    }
    read_only_vars = {
        "author_handle",
        "author_name",
        "created_at",
        "id",
        "modified_at",
        "url",
    }

    def __init__(
        self_,
        layout_type: DashboardLayoutType,
        title: str,
        widgets: List[Widget],
        author_handle: Union[str, UnsetType] = unset,
        author_name: Union[str, none_type, UnsetType] = unset,
        created_at: Union[datetime, UnsetType] = unset,
        description: Union[str, none_type, UnsetType] = unset,
        id: Union[str, UnsetType] = unset,
        is_read_only: Union[bool, UnsetType] = unset,
        modified_at: Union[datetime, UnsetType] = unset,
        notify_list: Union[List[str], none_type, UnsetType] = unset,
        reflow_type: Union[DashboardReflowType, UnsetType] = unset,
        restricted_roles: Union[List[str], UnsetType] = unset,
        template_variable_presets: Union[List[DashboardTemplateVariablePreset], none_type, UnsetType] = unset,
        template_variables: Union[List[DashboardTemplateVariable], none_type, UnsetType] = unset,
        url: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        A dashboard is Datadog’s tool for visually tracking, analyzing, and displaying
        key performance metrics, which enable you to monitor the health of your infrastructure.

        :param author_handle: Identifier of the dashboard author.
        :type author_handle: str, optional

        :param author_name: Name of the dashboard author.
        :type author_name: str, none_type, optional

        :param created_at: Creation date of the dashboard.
        :type created_at: datetime, optional

        :param description: Description of the dashboard.
        :type description: str, none_type, optional

        :param id: ID of the dashboard.
        :type id: str, optional

        :param is_read_only: Whether this dashboard is read-only. If True, only the author and admins can make changes to it. Prefer using ``restricted_roles`` to manage write authorization. **Deprecated**.
        :type is_read_only: bool, optional

        :param layout_type: Layout type of the dashboard.
        :type layout_type: DashboardLayoutType

        :param modified_at: Modification date of the dashboard.
        :type modified_at: datetime, optional

        :param notify_list: List of handles of users to notify when changes are made to this dashboard.
        :type notify_list: [str], none_type, optional

        :param reflow_type: Reflow type for a **new dashboard layout** dashboard. Set this only when layout type is 'ordered'.
            If set to 'fixed', the dashboard expects all widgets to have a layout, and if it's set to 'auto',
            widgets should not have layouts.
        :type reflow_type: DashboardReflowType, optional

        :param restricted_roles: A list of role identifiers. Only the author and users associated with at least one of these roles can edit this dashboard.
        :type restricted_roles: [str], optional

        :param template_variable_presets: Array of template variables saved views.
        :type template_variable_presets: [DashboardTemplateVariablePreset], none_type, optional

        :param template_variables: List of template variables for this dashboard.
        :type template_variables: [DashboardTemplateVariable], none_type, optional

        :param title: Title of the dashboard.
        :type title: str

        :param url: The URL of the dashboard.
        :type url: str, optional

        :param widgets: List of widgets to display on the dashboard.
        :type widgets: [Widget]
        """
        if author_handle is not unset:
            kwargs["author_handle"] = author_handle
        if author_name is not unset:
            kwargs["author_name"] = author_name
        if created_at is not unset:
            kwargs["created_at"] = created_at
        if description is not unset:
            kwargs["description"] = description
        if id is not unset:
            kwargs["id"] = id
        if is_read_only is not unset:
            kwargs["is_read_only"] = is_read_only
        if modified_at is not unset:
            kwargs["modified_at"] = modified_at
        if notify_list is not unset:
            kwargs["notify_list"] = notify_list
        if reflow_type is not unset:
            kwargs["reflow_type"] = reflow_type
        if restricted_roles is not unset:
            kwargs["restricted_roles"] = restricted_roles
        if template_variable_presets is not unset:
            kwargs["template_variable_presets"] = template_variable_presets
        if template_variables is not unset:
            kwargs["template_variables"] = template_variables
        if url is not unset:
            kwargs["url"] = url
        super().__init__(kwargs)

        self_.layout_type = layout_type
        self_.title = title
        self_.widgets = widgets



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.notebook_markdown_cell_definition import NotebookMarkdownCellDefinition


class NotebookMarkdownCellAttributes(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.notebook_markdown_cell_definition import NotebookMarkdownCellDefinition

        return {
            "definition": (NotebookMarkdownCellDefinition,),
        }

    attribute_map = {
        "definition": "definition",
    }

    def __init__(self_, definition: NotebookMarkdownCellDefinition, **kwargs):
        """
        The attributes of a notebook ``markdown`` cell.

        :param definition: Text in a notebook is formatted with `Markdown <https://daringfireball.net/projects/markdown/>`_ , which enables the use of headings, subheadings, links, images, lists, and code blocks.
        :type definition: NotebookMarkdownCellDefinition
        """
        super().__init__(kwargs)

        self_.definition = definition



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class ConfluentAccountUpdateRequestAttributes(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "api_key": (str,),
            "api_secret": (str,),
            "tags": ([str],),
        }

    attribute_map = {
        "api_key": "api_key",
        "api_secret": "api_secret",
        "tags": "tags",
    }

    def __init__(self_, api_key: str, api_secret: str, tags: Union[List[str], UnsetType] = unset, **kwargs):
        """
        Attributes object for updating a Confluent account.

        :param api_key: The API key associated with your Confluent account.
        :type api_key: str

        :param api_secret: The API secret associated with your Confluent account.
        :type api_secret: str

        :param tags: A list of strings representing tags. Can be a single key, or key-value pairs separated by a colon.
        :type tags: [str], optional
        """
        if tags is not unset:
            kwargs["tags"] = tags
        super().__init__(kwargs)

        self_.api_key = api_key
        self_.api_secret = api_secret



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.synthetics_private_location import SyntheticsPrivateLocation
    from datadog_api_client.v1.model.synthetics_private_location_creation_response_result_encryption import (
        SyntheticsPrivateLocationCreationResponseResultEncryption,
    )


class SyntheticsPrivateLocationCreationResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.synthetics_private_location import SyntheticsPrivateLocation
        from datadog_api_client.v1.model.synthetics_private_location_creation_response_result_encryption import (
            SyntheticsPrivateLocationCreationResponseResultEncryption,
        )

        return {
            "config": (dict,),
            "private_location": (SyntheticsPrivateLocation,),
            "result_encryption": (SyntheticsPrivateLocationCreationResponseResultEncryption,),
        }

    attribute_map = {
        "config": "config",
        "private_location": "private_location",
        "result_encryption": "result_encryption",
    }

    def __init__(
        self_,
        config: Union[dict, UnsetType] = unset,
        private_location: Union[SyntheticsPrivateLocation, UnsetType] = unset,
        result_encryption: Union[SyntheticsPrivateLocationCreationResponseResultEncryption, UnsetType] = unset,
        **kwargs,
    ):
        """
        Object that contains the new private location, the public key for result encryption, and the configuration skeleton.

        :param config: Configuration skeleton for the private location. See installation instructions of the private location on how to use this configuration.
        :type config: dict, optional

        :param private_location: Object containing information about the private location to create.
        :type private_location: SyntheticsPrivateLocation, optional

        :param result_encryption: Public key for the result encryption.
        :type result_encryption: SyntheticsPrivateLocationCreationResponseResultEncryption, optional
        """
        if config is not unset:
            kwargs["config"] = config
        if private_location is not unset:
            kwargs["private_location"] = private_location
        if result_encryption is not unset:
            kwargs["result_encryption"] = result_encryption
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.api_key import ApiKey


class ApiKeyListResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.api_key import ApiKey

        return {
            "api_keys": ([ApiKey],),
        }

    attribute_map = {
        "api_keys": "api_keys",
    }

    def __init__(self_, api_keys: Union[List[ApiKey], UnsetType] = unset, **kwargs):
        """
        List of API and application keys available for a given organization.

        :param api_keys: Array of API keys.
        :type api_keys: [ApiKey], optional
        """
        if api_keys is not unset:
            kwargs["api_keys"] = api_keys
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class ApplicationKey(ModelNormal):
    validations = {
        "hash": {
            "max_length": 40,
            "min_length": 40,
        },
    }

    @cached_property
    def openapi_types(_):
        return {
            "hash": (str,),
            "name": (str,),
            "owner": (str,),
        }

    attribute_map = {
        "hash": "hash",
        "name": "name",
        "owner": "owner",
    }
    read_only_vars = {
        "hash",
        "owner",
    }

    def __init__(
        self_,
        hash: Union[str, UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        owner: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        An application key with its associated metadata.

        :param hash: Hash of an application key.
        :type hash: str, optional

        :param name: Name of an application key.
        :type name: str, optional

        :param owner: Owner of an application key.
        :type owner: str, optional
        """
        if hash is not unset:
            kwargs["hash"] = hash
        if name is not unset:
            kwargs["name"] = name
        if owner is not unset:
            kwargs["owner"] = owner
        super().__init__(kwargs)



"""
Create or update service definition returns "CREATED" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.service_definition_api import ServiceDefinitionApi
from datadog_api_client.v2.model.service_definition_v2 import ServiceDefinitionV2
from datadog_api_client.v2.model.service_definition_v2_doc import ServiceDefinitionV2Doc
from datadog_api_client.v2.model.service_definition_v2_email import ServiceDefinitionV2Email
from datadog_api_client.v2.model.service_definition_v2_email_type import ServiceDefinitionV2EmailType
from datadog_api_client.v2.model.service_definition_v2_integrations import ServiceDefinitionV2Integrations
from datadog_api_client.v2.model.service_definition_v2_link import ServiceDefinitionV2Link
from datadog_api_client.v2.model.service_definition_v2_link_type import ServiceDefinitionV2LinkType
from datadog_api_client.v2.model.service_definition_v2_opsgenie import ServiceDefinitionV2Opsgenie
from datadog_api_client.v2.model.service_definition_v2_opsgenie_region import ServiceDefinitionV2OpsgenieRegion
from datadog_api_client.v2.model.service_definition_v2_repo import ServiceDefinitionV2Repo
from datadog_api_client.v2.model.service_definition_v2_version import ServiceDefinitionV2Version

body = ServiceDefinitionV2(
    contacts=[
        ServiceDefinitionV2Email(
            contact="contact@datadoghq.com",
            name="Team Email",
            type=ServiceDefinitionV2EmailType.EMAIL,
        ),
    ],
    dd_service="service-Example-Create_or_update_service_definition_returns_CREATED_response",
    dd_team="my-team",
    docs=[
        ServiceDefinitionV2Doc(
            name="Architecture",
            provider="google drive",
            url="https://gdrive/mydoc",
        ),
    ],
    extensions=dict(myorgextension="extensionvalue"),
    integrations=ServiceDefinitionV2Integrations(
        opsgenie=ServiceDefinitionV2Opsgenie(
            region=ServiceDefinitionV2OpsgenieRegion.US,
            service_url="https://my-org.opsgenie.com/service/123e4567-e89b-12d3-a456-426614174000",
        ),
        pagerduty="https://my-org.pagerduty.com/service-directory/PMyService",
    ),
    links=[
        ServiceDefinitionV2Link(
            name="Runbook",
            type=ServiceDefinitionV2LinkType.RUNBOOK,
            url="https://my-runbook",
        ),
    ],
    repos=[
        ServiceDefinitionV2Repo(
            name="Source Code",
            provider="GitHub",
            url="https://github.com/DataDog/schema",
        ),
    ],
    schema_version=ServiceDefinitionV2Version.V2,
    tags=[
        "my:tag",
        "service:tag",
    ],
    team="my-team",
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = ServiceDefinitionApi(api_client)
    response = api_instance.create_or_update_service_definitions(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    datetime,
    none_type,
    unset,
    UnsetType,
)


class UsageCloudSecurityPostureManagementHour(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "aas_host_count": (float, none_type),
            "aws_host_count": (float, none_type),
            "azure_host_count": (float, none_type),
            "compliance_host_count": (float, none_type),
            "container_count": (float, none_type),
            "gcp_host_count": (float, none_type),
            "host_count": (float, none_type),
            "hour": (datetime,),
            "org_name": (str,),
            "public_id": (str,),
        }

    attribute_map = {
        "aas_host_count": "aas_host_count",
        "aws_host_count": "aws_host_count",
        "azure_host_count": "azure_host_count",
        "compliance_host_count": "compliance_host_count",
        "container_count": "container_count",
        "gcp_host_count": "gcp_host_count",
        "host_count": "host_count",
        "hour": "hour",
        "org_name": "org_name",
        "public_id": "public_id",
    }

    def __init__(
        self_,
        aas_host_count: Union[float, none_type, UnsetType] = unset,
        aws_host_count: Union[float, none_type, UnsetType] = unset,
        azure_host_count: Union[float, none_type, UnsetType] = unset,
        compliance_host_count: Union[float, none_type, UnsetType] = unset,
        container_count: Union[float, none_type, UnsetType] = unset,
        gcp_host_count: Union[float, none_type, UnsetType] = unset,
        host_count: Union[float, none_type, UnsetType] = unset,
        hour: Union[datetime, UnsetType] = unset,
        org_name: Union[str, UnsetType] = unset,
        public_id: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Cloud Security Posture Management usage for a given organization for a given hour.

        :param aas_host_count: The number of Cloud Security Posture Management Azure app services hosts during a given hour.
        :type aas_host_count: float, none_type, optional

        :param aws_host_count: The number of Cloud Security Posture Management AWS hosts during a given hour.
        :type aws_host_count: float, none_type, optional

        :param azure_host_count: The number of Cloud Security Posture Management Azure hosts during a given hour.
        :type azure_host_count: float, none_type, optional

        :param compliance_host_count: The number of Cloud Security Posture Management hosts during a given hour.
        :type compliance_host_count: float, none_type, optional

        :param container_count: The total number of Cloud Security Posture Management containers during a given hour.
        :type container_count: float, none_type, optional

        :param gcp_host_count: The number of Cloud Security Posture Management GCP hosts during a given hour.
        :type gcp_host_count: float, none_type, optional

        :param host_count: The total number of Cloud Security Posture Management hosts during a given hour.
        :type host_count: float, none_type, optional

        :param hour: The hour for the usage.
        :type hour: datetime, optional

        :param org_name: The organization name.
        :type org_name: str, optional

        :param public_id: The organization public ID.
        :type public_id: str, optional
        """
        if aas_host_count is not unset:
            kwargs["aas_host_count"] = aas_host_count
        if aws_host_count is not unset:
            kwargs["aws_host_count"] = aws_host_count
        if azure_host_count is not unset:
            kwargs["azure_host_count"] = azure_host_count
        if compliance_host_count is not unset:
            kwargs["compliance_host_count"] = compliance_host_count
        if container_count is not unset:
            kwargs["container_count"] = container_count
        if gcp_host_count is not unset:
            kwargs["gcp_host_count"] = gcp_host_count
        if host_count is not unset:
            kwargs["host_count"] = host_count
        if hour is not unset:
            kwargs["hour"] = hour
        if org_name is not unset:
            kwargs["org_name"] = org_name
        if public_id is not unset:
            kwargs["public_id"] = public_id
        super().__init__(kwargs)
